clx-20220630

false 2022 FY 0000021076 http://fasb.org/us-gaap/2022#AccountingStandardsUpdate201602Member P3Y http://fasb.org/us-gaap/2022#OtherAssetsNoncurrent http://fasb.org/us-gaap/2022#OtherAssetsNoncurrent http://fasb.org/us-gaap/2022#AccountsPayableAndAccruedLiabilitiesCurrent http://fasb.org/us-gaap/2022#AccountsPayableAndAccruedLiabilitiesCurrent http://fasb.org/us-gaap/2022#OtherLiabilitiesNoncurrent http://fasb.org/us-gaap/2022#OtherLiabilitiesNoncurrent 0000021076 2021-07-01 2022-06-30 0000021076 2021-12-31 iso4217:USD 0000021076 2022-07-25 xbrli:shares 0000021076 2020-07-01 2021-06-30 0000021076 2019-07-01 2020-06-30 iso4217:USD xbrli:shares 0000021076 2022-06-30 0000021076 2021-06-30 0000021076 us-gaap:CommonStockMember 2019-06-30 0000021076 us-gaap:AdditionalPaidInCapitalMember 2019-06-30 0000021076 us-gaap:RetainedEarningsMember 2019-06-30 0000021076 us-gaap:TreasuryStockCommonMember 2019-06-30 0000021076 us-gaap:AccumulatedOtherComprehensiveIncomeMember 2019-06-30 0000021076 us-gaap:NoncontrollingInterestMember 2019-06-30 0000021076 2019-06-30 0000021076 us-gaap:RetainedEarningsMember srt:CumulativeEffectPeriodOfAdoptionAdjustmentMember 2019-06-30 0000021076 srt:CumulativeEffectPeriodOfAdoptionAdjustmentMember 2019-06-30 0000021076 us-gaap:RetainedEarningsMember 2019-07-01 2020-06-30 0000021076 us-gaap:AccumulatedOtherComprehensiveIncomeMember 2019-07-01 2020-06-30 0000021076 us-gaap:AdditionalPaidInCapitalMember 2019-07-01 2020-06-30 0000021076 us-gaap:TreasuryStockCommonMember 2019-07-01 2020-06-30 0000021076 us-gaap:CommonStockMember 2020-06-30 0000021076 us-gaap:AdditionalPaidInCapitalMember 2020-06-30 0000021076 us-gaap:RetainedEarningsMember 2020-06-30 0000021076 us-gaap:TreasuryStockCommonMember 2020-06-30 0000021076 us-gaap:AccumulatedOtherComprehensiveIncomeMember 2020-06-30 0000021076 us-gaap:NoncontrollingInterestMember 2020-06-30 0000021076 2020-06-30 0000021076 us-gaap:RetainedEarningsMember 2020-07-01 2021-06-30 0000021076 us-gaap:NoncontrollingInterestMember 2020-07-01 2021-06-30 0000021076 us-gaap:AccumulatedOtherComprehensiveIncomeMember 2020-07-01 2021-06-30 0000021076 us-gaap:AdditionalPaidInCapitalMember 2020-07-01 2021-06-30 0000021076 us-gaap:TreasuryStockCommonMember 2020-07-01 2021-06-30 0000021076 us-gaap:CommonStockMember 2020-07-01 2021-06-30 0000021076 us-gaap:CommonStockMember 2021-06-30 0000021076 us-gaap:AdditionalPaidInCapitalMember 2021-06-30 0000021076 us-gaap:RetainedEarningsMember 2021-06-30 0000021076 us-gaap:TreasuryStockCommonMember 2021-06-30 0000021076 us-gaap:AccumulatedOtherComprehensiveIncomeMember 2021-06-30 0000021076 us-gaap:NoncontrollingInterestMember 2021-06-30 0000021076 us-gaap:RetainedEarningsMember 2021-07-01 2022-06-30 0000021076 us-gaap:NoncontrollingInterestMember 2021-07-01 2022-06-30 0000021076 us-gaap:AccumulatedOtherComprehensiveIncomeMember 2021-07-01 2022-06-30 0000021076 us-gaap:AdditionalPaidInCapitalMember 2021-07-01 2022-06-30 0000021076 us-gaap:TreasuryStockCommonMember 2021-07-01 2022-06-30 0000021076 us-gaap:CommonStockMember 2022-06-30 0000021076 us-gaap:AdditionalPaidInCapitalMember 2022-06-30 0000021076 us-gaap:RetainedEarningsMember 2022-06-30 0000021076 us-gaap:TreasuryStockCommonMember 2022-06-30 0000021076 us-gaap:AccumulatedOtherComprehensiveIncomeMember 2022-06-30 0000021076 us-gaap:NoncontrollingInterestMember 2022-06-30 0000021076 2018-07-01 2019-06-30 0000021076 srt:MinimumMember us-gaap:BuildingAndBuildingImprovementsMember 2021-07-01 2022-06-30 0000021076 us-gaap:BuildingAndBuildingImprovementsMember srt:MaximumMember 2021-07-01 2022-06-30 0000021076 us-gaap:LandImprovementsMember srt:MinimumMember 2021-07-01 2022-06-30 0000021076 us-gaap:LandImprovementsMember srt:MaximumMember 2021-07-01 2022-06-30 0000021076 srt:MinimumMember us-gaap:MachineryAndEquipmentMember 2021-07-01 2022-06-30 0000021076 srt:MaximumMember us-gaap:MachineryAndEquipmentMember 2021-07-01 2022-06-30 0000021076 srt:MinimumMember us-gaap:ComputerEquipmentMember 2021-07-01 2022-06-30 0000021076 us-gaap:ComputerEquipmentMember srt:MaximumMember 2021-07-01 2022-06-30 0000021076 us-gaap:SoftwareAndSoftwareDevelopmentCostsMember srt:MinimumMember 2021-07-01 2022-06-30 0000021076 us-gaap:SoftwareAndSoftwareDevelopmentCostsMember srt:MaximumMember 2021-07-01 2022-06-30 0000021076 srt:MinimumMember 2021-07-01 2022-06-30 0000021076 srt:MaximumMember 2021-07-01 2022-06-30 xbrli:pure clx:instrument 0000021076 clx:JointVentureInKingdomOfSaudiArabiaMember clx:JointVentureInKingdomOfSaudiArabiaMember 2020-07-09 clx:entity 0000021076 clx:JointVentureInKingdomOfSaudiArabiaMember 2020-06-30 0000021076 clx:JointVentureInKingdomOfSaudiArabiaMember 2020-07-09 0000021076 clx:JointVentureInKingdomOfSaudiArabiaMember 2020-07-09 2020-07-09 0000021076 clx:JointVentureInKingdomOfSaudiArabiaMember 2020-07-09 0000021076 clx:JointVentureInKingdomOfSaudiArabiaMember 2020-07-01 2020-09-30 0000021076 clx:JointVentureInKingdomOfSaudiArabiaMember us-gaap:ContractualRightsMember 2020-07-09 0000021076 us-gaap:CustomerRelationshipsMember clx:JointVentureInKingdomOfSaudiArabiaMember 2020-07-09 0000021076 clx:JointVentureInKingdomOfSaudiArabiaMember 2020-07-01 2021-06-30 0000021076 clx:JointVentureInKingdomOfSaudiArabiaMember 2021-07-01 2022-06-30 0000021076 us-gaap:MachineryAndEquipmentMember 2022-06-30 0000021076 us-gaap:MachineryAndEquipmentMember 2021-06-30 0000021076 us-gaap:BuildingMember 2022-06-30 0000021076 us-gaap:BuildingMember 2021-06-30 0000021076 us-gaap:SoftwareAndSoftwareDevelopmentCostsMember 2022-06-30 0000021076 us-gaap:SoftwareAndSoftwareDevelopmentCostsMember 2021-06-30 0000021076 us-gaap:LandAndLandImprovementsMember 2022-06-30 0000021076 us-gaap:LandAndLandImprovementsMember 2021-06-30 0000021076 us-gaap:ConstructionInProgressMember 2022-06-30 0000021076 us-gaap:ConstructionInProgressMember 2021-06-30 0000021076 us-gaap:ComputerEquipmentMember 2022-06-30 0000021076 us-gaap:ComputerEquipmentMember 2021-06-30 0000021076 us-gaap:PropertyPlantAndEquipmentMember 2021-07-01 2022-06-30 0000021076 us-gaap:PropertyPlantAndEquipmentMember 2020-07-01 2021-06-30 0000021076 us-gaap:PropertyPlantAndEquipmentMember 2019-07-01 2020-06-30 0000021076 us-gaap:SoftwareAndSoftwareDevelopmentCostsMember 2021-07-01 2022-06-30 0000021076 us-gaap:SoftwareAndSoftwareDevelopmentCostsMember 2020-07-01 2021-06-30 0000021076 us-gaap:SoftwareAndSoftwareDevelopmentCostsMember 2019-07-01 2020-06-30 0000021076 clx:HealthAndWellnessMember 2020-06-30 0000021076 clx:HouseholdMember 2020-06-30 0000021076 clx:LifestyleMember 2020-06-30 0000021076 clx:InternationalMember 2020-06-30 0000021076 clx:HealthAndWellnessMember 2020-07-01 2021-06-30 0000021076 clx:HouseholdMember 2020-07-01 2021-06-30 0000021076 clx:LifestyleMember 2020-07-01 2021-06-30 0000021076 clx:InternationalMember 2020-07-01 2021-06-30 0000021076 clx:HealthAndWellnessMember 2021-06-30 0000021076 clx:HouseholdMember 2021-06-30 0000021076 clx:LifestyleMember 2021-06-30 0000021076 clx:InternationalMember 2021-06-30 0000021076 clx:HealthAndWellnessMember 2021-07-01 2022-06-30 0000021076 clx:HouseholdMember 2021-07-01 2022-06-30 0000021076 clx:LifestyleMember 2021-07-01 2022-06-30 0000021076 clx:InternationalMember 2021-07-01 2022-06-30 0000021076 clx:HealthAndWellnessMember 2022-06-30 0000021076 clx:HouseholdMember 2022-06-30 0000021076 clx:LifestyleMember 2022-06-30 0000021076 clx:InternationalMember 2022-06-30 0000021076 us-gaap:TrademarksMember 2022-06-30 0000021076 us-gaap:TrademarksMember 2021-06-30 0000021076 us-gaap:TrademarksMember 2022-06-30 0000021076 us-gaap:TrademarksMember 2021-06-30 0000021076 us-gaap:OtherIntangibleAssetsMember 2022-06-30 0000021076 us-gaap:OtherIntangibleAssetsMember 2021-06-30 0000021076 clx:VitaminsMineralsAndSupplementsMember clx:HealthAndWellnessMember 2020-07-01 2021-06-30 0000021076 clx:VitaminsMineralsAndSupplementsMember us-gaap:TrademarksMember clx:HealthAndWellnessMember 2020-07-01 2021-06-30 0000021076 clx:VitaminsMineralsAndSupplementsMember us-gaap:OtherIntangibleAssetsMember clx:HealthAndWellnessMember 2020-07-01 2021-06-30 0000021076 us-gaap:DistributionRightsMember 2020-07-01 2021-06-30 0000021076 us-gaap:DistributionRightsMember 2021-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures3.80300DueNovember2021Member 2022-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures3.80300DueNovember2021Member 2021-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures3.05600DueSeptember2022Member 2022-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures3.05600DueSeptember2022Member 2021-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures3.50500DueDecember2024Member 2022-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures3.50500DueDecember2024Member 2021-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures3.10400DueOctober2027Member 2022-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures3.10400DueOctober2027Member 2021-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures3.90500DueMay2028Member 2022-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures3.90500DueMay2028Member 2021-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures440500DueMay2029Member 2022-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures440500DueMay2029Member 2021-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures180500DueMay2030Member 2022-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures180500DueMay2030Member 2021-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures460600DueMay2032Member 2022-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures460600DueMay2032Member 2021-06-30 0000021076 us-gaap:SeniorNotesMember 2022-05-31 0000021076 clx:SeniorLongTermNotesAndDebentures440500DueMay2029Member us-gaap:SeniorNotesMember 2022-05-31 0000021076 clx:SeniorLongTermNotesAndDebentures460600DueMay2032Member us-gaap:SeniorNotesMember 2022-05-31 0000021076 us-gaap:SeniorNotesMember clx:SeniorLongTermNotesAndDebentures3.05600DueSeptember2022Member 2022-06-30 0000021076 us-gaap:SeniorNotesMember clx:SeniorLongTermNotesAndDebentures3.50500DueDecember2024Member 2022-06-30 0000021076 us-gaap:SeniorNotesMember clx:SeniorLongTermNotesAndDebentures3.50500DueDecember2024Member 2022-06-01 2022-06-30 0000021076 us-gaap:SeniorNotesMember clx:SeniorLongTermNotesAndDebentures3.80300DueNovember2021Member 2021-11-01 2021-11-30 0000021076 us-gaap:SeniorNotesMember clx:SeniorLongTermNotesAndDebentures3.80300DueNovember2021Member 2021-11-30 0000021076 clx:RevolvingCreditAgreementMaturesMarch2027Member us-gaap:RevolvingCreditFacilityMember 2022-03-25 0000021076 us-gaap:RevolvingCreditFacilityMember clx:RevolvingCreditAgreementMaturesNovember2024Member 2019-11-30 0000021076 2022-03-25 0000021076 us-gaap:RevolvingCreditFacilityMember 2022-06-30 0000021076 us-gaap:RevolvingCreditFacilityMember 2021-06-30 0000021076 us-gaap:ForeignLineOfCreditMember 2022-06-30 0000021076 us-gaap:ForeignLineOfCreditMember 2021-06-30 0000021076 clx:ForeignAndOtherCreditLinesMember 2022-06-30 0000021076 clx:ForeignAndOtherCreditLinesMember 2021-06-30 0000021076 clx:GladBusinessMember 2021-06-30 0000021076 clx:GladBusinessMember 2022-06-30 0000021076 clx:TotalCommodityPurchaseDerivativeContractsMember 2021-07-01 2022-06-30 0000021076 clx:TotalCommodityPurchaseDerivativeContractsMember 2022-06-30 0000021076 clx:SoybeanOilFuturesMember 2022-06-30 0000021076 clx:JetFuelSwapsMember 2022-06-30 0000021076 clx:TotalCommodityPurchaseDerivativeContractsMember 2021-06-30 0000021076 clx:SoybeanOilFuturesMember 2021-06-30 0000021076 clx:JetFuelSwapsMember 2021-06-30 0000021076 us-gaap:ForeignExchangeContractMember clx:PurchasesofInventoryMember 2022-06-30 0000021076 us-gaap:ForeignExchangeContractMember clx:PurchasesofInventoryMember 2021-06-30 0000021076 us-gaap:InterestRateContractMember 2022-06-30 0000021076 us-gaap:InterestRateContractMember 2021-06-30 0000021076 us-gaap:InterestRateContractMember 2021-07-01 2022-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures440500DueMay2029Member us-gaap:InterestRateContractMember 2021-07-01 2022-06-30 0000021076 clx:SeniorLongTermNotesAndDebentures460600DueMay2032Member us-gaap:InterestRateContractMember 2021-07-01 2022-06-30 0000021076 us-gaap:CommodityContractMember 2021-07-01 2022-06-30 0000021076 us-gaap:CommodityContractMember 2020-07-01 2021-06-30 0000021076 us-gaap:CommodityContractMember 2019-07-01 2020-06-30 0000021076 us-gaap:ForeignExchangeContractMember 2021-07-01 2022-06-30 0000021076 us-gaap:ForeignExchangeContractMember 2020-07-01 2021-06-30 0000021076 us-gaap:ForeignExchangeContractMember 2019-07-01 2020-06-30 0000021076 us-gaap:InterestRateContractMember 2020-07-01 2021-06-30 0000021076 us-gaap:InterestRateContractMember 2019-07-01 2020-06-30 0000021076 clx:SoybeanOilFuturesMember us-gaap:CommodityContractMember 2022-06-30 0000021076 clx:SoybeanOilFuturesMember us-gaap:CommodityContractMember 2021-06-30 0000021076 clx:TrustAssetsForNonqualifiedDeferredCompensationPlansMember us-gaap:OtherAssetsMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel1Member 2021-07-01 2022-06-30 0000021076 us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:CommodityContractMember us-gaap:FairValueInputsLevel1Member 2022-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:CommodityContractMember us-gaap:FairValueInputsLevel1Member 2022-06-30 0000021076 us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:CommodityContractMember us-gaap:FairValueInputsLevel1Member 2021-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:CommodityContractMember us-gaap:FairValueInputsLevel1Member 2021-06-30 0000021076 us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member us-gaap:CommodityContractMember 2022-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member us-gaap:CommodityContractMember 2022-06-30 0000021076 us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member us-gaap:CommodityContractMember 2021-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member us-gaap:CommodityContractMember 2021-06-30 0000021076 us-gaap:ForeignExchangeForwardMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2022-06-30 0000021076 us-gaap:ForeignExchangeForwardMember us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2022-06-30 0000021076 us-gaap:ForeignExchangeForwardMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2021-06-30 0000021076 us-gaap:ForeignExchangeForwardMember us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2021-06-30 0000021076 us-gaap:InterestRateContractMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2022-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:InterestRateContractMember us-gaap:FairValueInputsLevel2Member 2022-06-30 0000021076 us-gaap:InterestRateContractMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2021-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:InterestRateContractMember us-gaap:FairValueInputsLevel2Member 2021-06-30 0000021076 us-gaap:CarryingReportedAmountFairValueDisclosureMember 2022-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember 2022-06-30 0000021076 us-gaap:CarryingReportedAmountFairValueDisclosureMember 2021-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember 2021-06-30 0000021076 us-gaap:MoneyMarketFundsMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel1Member 2022-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:MoneyMarketFundsMember us-gaap:FairValueInputsLevel1Member 2022-06-30 0000021076 us-gaap:MoneyMarketFundsMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel1Member 2021-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:MoneyMarketFundsMember us-gaap:FairValueInputsLevel1Member 2021-06-30 0000021076 us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member us-gaap:BankTimeDepositsMember 2022-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member us-gaap:BankTimeDepositsMember 2022-06-30 0000021076 us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member us-gaap:BankTimeDepositsMember 2021-06-30 0000021076 us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member us-gaap:BankTimeDepositsMember 2021-06-30 0000021076 clx:TrustAssetsForNonqualifiedDeferredCompensationPlansMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel1Member 2022-06-30 0000021076 clx:TrustAssetsForNonqualifiedDeferredCompensationPlansMember us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel1Member 2022-06-30 0000021076 clx:TrustAssetsForNonqualifiedDeferredCompensationPlansMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel1Member 2021-06-30 0000021076 clx:TrustAssetsForNonqualifiedDeferredCompensationPlansMember us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel1Member 2021-06-30 0000021076 clx:NotesAndLoansPayableMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2022-06-30 0000021076 clx:NotesAndLoansPayableMember us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2022-06-30 0000021076 clx:NotesAndLoansPayableMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2021-06-30 0000021076 clx:NotesAndLoansPayableMember us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2021-06-30 0000021076 us-gaap:LongTermDebtMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2022-06-30 0000021076 us-gaap:LongTermDebtMember us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2022-06-30 0000021076 us-gaap:LongTermDebtMember us-gaap:CarryingReportedAmountFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2021-06-30 0000021076 us-gaap:LongTermDebtMember us-gaap:EstimateOfFairValueFairValueDisclosureMember us-gaap:FairValueInputsLevel2Member 2021-06-30 0000021076 clx:AlamedaCountyCaliforniaMatterMember 2021-06-30 0000021076 clx:AlamedaCountyCaliforniaMatterMember 2022-06-30 0000021076 clx:AlamedaCountyCaliforniaMatterMember 2021-07-01 2022-06-30 0000021076 clx:DickinsonCountyMichiganMatterMember 2022-06-30 0000021076 clx:DickinsonCountyMichiganMatterMember 2021-06-30 0000021076 clx:DickinsonCountyMichiganMatterMember 2021-07-01 2022-06-30 0000021076 2022-05-25 2022-05-25 0000021076 2022-05-25 0000021076 us-gaap:TreasuryStockMember 2020-11-18 2020-11-18 0000021076 us-gaap:SubsequentEventMember 2022-07-12 2022-07-12 0000021076 us-gaap:AccumulatedTranslationAdjustmentMember 2019-06-30 0000021076 us-gaap:AccumulatedNetGainLossFromDesignatedOrQualifyingCashFlowHedgesMember 2019-06-30 0000021076 us-gaap:AccumulatedDefinedBenefitPlansAdjustmentMember 2019-06-30 0000021076 us-gaap:AccumulatedTranslationAdjustmentMember 2019-07-01 2020-06-30 0000021076 us-gaap:AccumulatedNetGainLossFromDesignatedOrQualifyingCashFlowHedgesMember 2019-07-01 2020-06-30 0000021076 us-gaap:AccumulatedDefinedBenefitPlansAdjustmentMember 2019-07-01 2020-06-30 0000021076 us-gaap:AccumulatedTranslationAdjustmentMember 2020-06-30 0000021076 us-gaap:AccumulatedNetGainLossFromDesignatedOrQualifyingCashFlowHedgesMember 2020-06-30 0000021076 us-gaap:AccumulatedDefinedBenefitPlansAdjustmentMember 2020-06-30 0000021076 us-gaap:AccumulatedTranslationAdjustmentMember 2020-07-01 2021-06-30 0000021076 us-gaap:AccumulatedNetGainLossFromDesignatedOrQualifyingCashFlowHedgesMember 2020-07-01 2021-06-30 0000021076 us-gaap:AccumulatedDefinedBenefitPlansAdjustmentMember 2020-07-01 2021-06-30 0000021076 us-gaap:AccumulatedTranslationAdjustmentMember 2021-06-30 0000021076 us-gaap:AccumulatedNetGainLossFromDesignatedOrQualifyingCashFlowHedgesMember 2021-06-30 0000021076 us-gaap:AccumulatedDefinedBenefitPlansAdjustmentMember 2021-06-30 0000021076 us-gaap:AccumulatedTranslationAdjustmentMember 2021-07-01 2022-06-30 0000021076 us-gaap:AccumulatedNetGainLossFromDesignatedOrQualifyingCashFlowHedgesMember 2021-07-01 2022-06-30 0000021076 us-gaap:AccumulatedDefinedBenefitPlansAdjustmentMember 2021-07-01 2022-06-30 0000021076 us-gaap:AccumulatedTranslationAdjustmentMember 2022-06-30 0000021076 us-gaap:AccumulatedNetGainLossFromDesignatedOrQualifyingCashFlowHedgesMember 2022-06-30 0000021076 us-gaap:AccumulatedDefinedBenefitPlansAdjustmentMember 2022-06-30 0000021076 clx:LongTermInterCompanyLoansMember 2021-07-01 2022-06-30 0000021076 clx:LongTermInterCompanyLoansMember 2020-07-01 2021-06-30 0000021076 clx:LongTermInterCompanyLoansMember 2019-07-01 2020-06-30 0000021076 2012-11-01 2012-11-30 0000021076 us-gaap:CostOfSalesMember 2021-07-01 2022-06-30 0000021076 us-gaap:CostOfSalesMember 2020-07-01 2021-06-30 0000021076 us-gaap:CostOfSalesMember 2019-07-01 2020-06-30 0000021076 us-gaap:SellingGeneralAndAdministrativeExpensesMember 2021-07-01 2022-06-30 0000021076 us-gaap:SellingGeneralAndAdministrativeExpensesMember 2020-07-01 2021-06-30 0000021076 us-gaap:SellingGeneralAndAdministrativeExpensesMember 2019-07-01 2020-06-30 0000021076 us-gaap:ResearchAndDevelopmentExpenseMember 2021-07-01 2022-06-30 0000021076 us-gaap:ResearchAndDevelopmentExpenseMember 2020-07-01 2021-06-30 0000021076 us-gaap:ResearchAndDevelopmentExpenseMember 2019-07-01 2020-06-30 0000021076 us-gaap:EmployeeStockOptionMember 2021-07-01 2022-06-30 0000021076 srt:MinimumMember us-gaap:EmployeeStockOptionMember 2020-07-01 2021-06-30 0000021076 us-gaap:EmployeeStockOptionMember srt:MaximumMember 2020-07-01 2021-06-30 0000021076 us-gaap:EmployeeStockOptionMember 2019-07-01 2020-06-30 0000021076 us-gaap:EmployeeStockOptionMember 2020-07-01 2021-06-30 0000021076 srt:MinimumMember us-gaap:EmployeeStockOptionMember 2021-07-01 2022-06-30 0000021076 us-gaap:EmployeeStockOptionMember srt:MaximumMember 2021-07-01 2022-06-30 0000021076 us-gaap:EmployeeStockOptionMember 2022-06-30 0000021076 srt:MinimumMember us-gaap:RestrictedStockMember 2021-07-01 2022-06-30 0000021076 srt:MaximumMember us-gaap:RestrictedStockMember 2021-07-01 2022-06-30 0000021076 us-gaap:RestrictedStockMember 2022-06-30 0000021076 us-gaap:RestrictedStockMember 2021-07-01 2022-06-30 0000021076 us-gaap:RestrictedStockMember 2020-07-01 2021-06-30 0000021076 us-gaap:RestrictedStockMember 2019-07-01 2020-06-30 0000021076 us-gaap:RestrictedStockMember 2021-06-30 0000021076 us-gaap:PerformanceSharesMember 2022-06-30 0000021076 us-gaap:PerformanceSharesMember 2021-07-01 2022-06-30 0000021076 us-gaap:PerformanceSharesMember 2020-07-01 2021-06-30 0000021076 us-gaap:PerformanceSharesMember 2019-07-01 2020-06-30 0000021076 us-gaap:PerformanceSharesMember 2021-06-30 0000021076 clx:DeferredStockUnitsForNonemployeeDirectorsMember 2021-07-01 2022-06-30 0000021076 clx:DeferredStockUnitsForNonemployeeDirectorsMember 2022-06-30 0000021076 us-gaap:DomesticCountryMember clx:ForeignTaxCreditCarryforwardMember 2022-06-30 0000021076 us-gaap:DomesticCountryMember clx:USJurisdictionTaxCreditCarryforwardMember clx:SubjectToExpirationMember 2022-06-30 0000021076 us-gaap:DomesticCountryMember clx:USJurisdictionTaxCreditCarryforwardMember clx:NotSubjectToExpirationMember 2022-06-30 0000021076 clx:ForeignTaxCreditCarryforwardMember us-gaap:ForeignCountryMember clx:NotSubjectToExpirationMember 2022-06-30 0000021076 us-gaap:DomesticCountryMember clx:SubjectToExpirationMember 2022-06-30 0000021076 us-gaap:DomesticCountryMember clx:NotSubjectToExpirationMember 2022-06-30 0000021076 us-gaap:ForeignCountryMember clx:SubjectToExpirationMember 2022-06-30 0000021076 us-gaap:ForeignCountryMember clx:NotSubjectToExpirationMember 2022-06-30 0000021076 clx:RetirementIncomeMember 2021-07-01 2022-06-30 0000021076 clx:RetirementIncomeMember 2020-07-01 2021-06-30 0000021076 clx:RetirementIncomeMember 2019-07-01 2020-06-30 0000021076 srt:MinimumMember clx:RetirementIncomeMember 2022-05-17 2022-05-17 0000021076 clx:RetirementIncomeMember srt:MaximumMember 2022-05-17 2022-05-17 0000021076 clx:RetirementIncomeMember 2022-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember 2021-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember 2020-06-30 0000021076 us-gaap:DefinedBenefitPostretirementHealthCoverageMember clx:RetirementHealthCareMember 2021-06-30 0000021076 us-gaap:DefinedBenefitPostretirementHealthCoverageMember clx:RetirementHealthCareMember 2020-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember 2021-07-01 2022-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember 2020-07-01 2021-06-30 0000021076 us-gaap:DefinedBenefitPostretirementHealthCoverageMember clx:RetirementHealthCareMember 2021-07-01 2022-06-30 0000021076 us-gaap:DefinedBenefitPostretirementHealthCoverageMember clx:RetirementHealthCareMember 2020-07-01 2021-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember 2022-06-30 0000021076 us-gaap:DefinedBenefitPostretirementHealthCoverageMember clx:RetirementHealthCareMember 2022-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember 2019-07-01 2020-06-30 0000021076 us-gaap:DefinedBenefitPostretirementHealthCoverageMember clx:RetirementHealthCareMember 2019-07-01 2020-06-30 0000021076 us-gaap:DefinedBenefitPlanEquitySecuritiesUsMember clx:RetirementIncomeMember 2022-06-30 0000021076 us-gaap:DefinedBenefitPlanEquitySecuritiesUsMember clx:RetirementIncomeMember 2021-06-30 0000021076 clx:RetirementIncomeMember us-gaap:DefinedBenefitPlanEquitySecuritiesNonUsMember 2022-06-30 0000021076 clx:RetirementIncomeMember us-gaap:DefinedBenefitPlanEquitySecuritiesNonUsMember 2021-06-30 0000021076 clx:RetirementIncomeMember us-gaap:FixedIncomeFundsMember 2022-06-30 0000021076 clx:RetirementIncomeMember us-gaap:FixedIncomeFundsMember 2021-06-30 0000021076 us-gaap:DefinedBenefitPlanRealEstateMember clx:RetirementIncomeMember 2022-06-30 0000021076 us-gaap:DefinedBenefitPlanRealEstateMember clx:RetirementIncomeMember 2021-06-30 0000021076 clx:RetirementIncomeMember 2021-06-30 0000021076 clx:DefinedBenefitPlanBondsFundsMember us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember us-gaap:FairValueMeasuredAtNetAssetValuePerShareMember 2022-06-30 0000021076 clx:DefinedBenefitPlanBondsFundsMember us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember us-gaap:FairValueMeasuredAtNetAssetValuePerShareMember 2021-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember us-gaap:FairValueMeasuredAtNetAssetValuePerShareMember us-gaap:DefinedBenefitPlanEquitySecuritiesNonUsMember 2022-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember us-gaap:FairValueMeasuredAtNetAssetValuePerShareMember us-gaap:DefinedBenefitPlanEquitySecuritiesNonUsMember 2021-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember us-gaap:DefinedBenefitPlanEquitySecuritiesUsMember clx:RetirementIncomeMember us-gaap:FairValueMeasuredAtNetAssetValuePerShareMember 2022-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember us-gaap:DefinedBenefitPlanEquitySecuritiesUsMember clx:RetirementIncomeMember us-gaap:FairValueMeasuredAtNetAssetValuePerShareMember 2021-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember us-gaap:FairValueMeasuredAtNetAssetValuePerShareMember clx:DefinedBenefitPlanShortTermInvestmentMember 2022-06-30 0000021076 us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember us-gaap:FairValueMeasuredAtNetAssetValuePerShareMember clx:DefinedBenefitPlanShortTermInvestmentMember 2021-06-30 0000021076 us-gaap:DefinedBenefitPlanRealEstateMember us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember us-gaap:FairValueMeasuredAtNetAssetValuePerShareMember 2022-06-30 0000021076 us-gaap:DefinedBenefitPlanRealEstateMember us-gaap:OtherPostretirementBenefitPlansDefinedBenefitMember clx:RetirementIncomeMember us-gaap:FairValueMeasuredAtNetAssetValuePerShareMember 2021-06-30 0000021076 clx:DomesticDefinedContributionPlanMember 2021-07-01 2022-06-30 0000021076 clx:DomesticDefinedContributionPlanMember 2020-07-01 2021-06-30 0000021076 clx:DomesticDefinedContributionPlanMember 2019-07-01 2020-06-30 0000021076 clx:InternationalDefinedContributionPlanMember 2021-07-01 2022-06-30 0000021076 clx:InternationalDefinedContributionPlanMember 2020-07-01 2021-06-30 0000021076 clx:InternationalDefinedContributionPlanMember 2019-07-01 2020-06-30 clx:segment 0000021076 us-gaap:OperatingSegmentsMember clx:HealthAndWellnessMember 2021-07-01 2022-06-30 0000021076 clx:HouseholdMember us-gaap:OperatingSegmentsMember 2021-07-01 2022-06-30 0000021076 clx:LifestyleMember us-gaap:OperatingSegmentsMember 2021-07-01 2022-06-30 0000021076 us-gaap:OperatingSegmentsMember clx:InternationalMember 2021-07-01 2022-06-30 0000021076 us-gaap:CorporateNonSegmentMember 2021-07-01 2022-06-30 0000021076 us-gaap:OperatingSegmentsMember clx:HealthAndWellnessMember 2020-07-01 2021-06-30 0000021076 clx:HouseholdMember us-gaap:OperatingSegmentsMember 2020-07-01 2021-06-30 0000021076 clx:LifestyleMember us-gaap:OperatingSegmentsMember 2020-07-01 2021-06-30 0000021076 us-gaap:OperatingSegmentsMember clx:InternationalMember 2020-07-01 2021-06-30 0000021076 us-gaap:CorporateNonSegmentMember 2020-07-01 2021-06-30 0000021076 us-gaap:OperatingSegmentsMember clx:HealthAndWellnessMember 2019-07-01 2020-06-30 0000021076 clx:HouseholdMember us-gaap:OperatingSegmentsMember 2019-07-01 2020-06-30 0000021076 clx:LifestyleMember us-gaap:OperatingSegmentsMember 2019-07-01 2020-06-30 0000021076 us-gaap:OperatingSegmentsMember clx:InternationalMember 2019-07-01 2020-06-30 0000021076 us-gaap:CorporateNonSegmentMember 2019-07-01 2020-06-30 0000021076 us-gaap:OperatingSegmentsMember clx:HealthAndWellnessMember 2022-06-30 0000021076 clx:HouseholdMember us-gaap:OperatingSegmentsMember 2022-06-30 0000021076 clx:LifestyleMember us-gaap:OperatingSegmentsMember 2022-06-30 0000021076 us-gaap:OperatingSegmentsMember clx:InternationalMember 2022-06-30 0000021076 us-gaap:CorporateNonSegmentMember 2022-06-30 0000021076 us-gaap:OperatingSegmentsMember clx:HealthAndWellnessMember 2021-06-30 0000021076 clx:HouseholdMember us-gaap:OperatingSegmentsMember 2021-06-30 0000021076 clx:LifestyleMember us-gaap:OperatingSegmentsMember 2021-06-30 0000021076 us-gaap:OperatingSegmentsMember clx:InternationalMember 2021-06-30 0000021076 us-gaap:CorporateNonSegmentMember 2021-06-30 0000021076 clx:WalmartStoresIncMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:CustomerConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 clx:WalmartStoresIncMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:CustomerConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 clx:WalmartStoresIncMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:CustomerConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 clx:CleaningMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2021-07-01 2022-06-30 0000021076 clx:CleaningMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2020-07-01 2021-06-30 0000021076 clx:CleaningMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:ProfessionalProductsMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:ProfessionalProductsMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:ProfessionalProductsMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:VitaminsMineralsAndSupplementsMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:VitaminsMineralsAndSupplementsMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:VitaminsMineralsAndSupplementsMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember clx:HealthAndWellnessMember 2019-07-01 2020-06-30 0000021076 clx:BagsAndWrapsMember us-gaap:RevenueFromContractWithCustomerMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 clx:BagsAndWrapsMember us-gaap:RevenueFromContractWithCustomerMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 clx:BagsAndWrapsMember us-gaap:RevenueFromContractWithCustomerMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember clx:GrillingMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember clx:GrillingMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember clx:GrillingMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:CatLitterMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:CatLitterMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:CatLitterMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:HouseholdMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember clx:FoodProductsMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember clx:FoodProductsMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember clx:FoodProductsMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember clx:NaturalPersonalCareMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember clx:NaturalPersonalCareMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember clx:NaturalPersonalCareMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember us-gaap:ProductConcentrationRiskMember clx:WaterFiltrationMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember us-gaap:ProductConcentrationRiskMember clx:WaterFiltrationMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember us-gaap:ProductConcentrationRiskMember clx:WaterFiltrationMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:LifestyleMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:InternationalMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:InternationalMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:InternationalMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 clx:CleaningMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 clx:CleaningMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 clx:CleaningMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 clx:BagsAndWrapsMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 clx:BagsAndWrapsMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 clx:BagsAndWrapsMember us-gaap:RevenueFromContractWithCustomerMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:FoodProductsMember us-gaap:ProductConcentrationRiskMember 2021-07-01 2022-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:FoodProductsMember us-gaap:ProductConcentrationRiskMember 2020-07-01 2021-06-30 0000021076 us-gaap:RevenueFromContractWithCustomerMember clx:FoodProductsMember us-gaap:ProductConcentrationRiskMember 2019-07-01 2020-06-30 0000021076 country:US 2021-07-01 2022-06-30 0000021076 clx:ForeignMember 2021-07-01 2022-06-30 0000021076 country:US 2020-07-01 2021-06-30 0000021076 clx:ForeignMember 2020-07-01 2021-06-30 0000021076 country:US 2019-07-01 2020-06-30 0000021076 clx:ForeignMember 2019-07-01 2020-06-30 0000021076 country:US 2022-06-30 0000021076 clx:ForeignMember 2022-06-30 0000021076 country:US 2021-06-30 0000021076 clx:ForeignMember 2021-06-30 0000021076 us-gaap:SubsequentEventMember 2022-08-03
Table of Contents

UNITED STATES
SECURITIES AND EXCHANGE COMMISSION
Washington, D.C. 20549
__________________
FORM 10-K
__________________

☑ | Annual report pursuant to Section 13 or 15(d) of the Securities Exchange Act of 1934
| for the fiscal year ended | June 30, 2022
OR
☐ | Transition report pursuant to Section 13 or 15(d) of the Securities Exchange Act of 1934
for the transition period from __________to__________.
| Commission file number: | 1-07151

THE CLOROX COMPANY
(Exact name of registrant as specified in its charter)

Delaware |  | 31-0595760
(State or other jurisdiction of |  | (I.R.S. Employer
incorporation or organization) |  | Identification Number)

1221 Broadway, Oakland, California 94612-1888

(Address of principal executive offices) (ZIP code)
|  | (510) | 271-7000 |  |
(Registrant’s telephone number, including area code)
Securities registered pursuant to Section 12(b) of the Act:
Title of each class | Trading Symbol(s) | Name of each exchange on which registered
Common Stock – $1.00 par value | CLX | New York Stock Exchange
Securities registered pursuant to Section 12(g) of the Act:
None
(Title of class)

Indicate by check mark if the registrant is a well-known seasoned issuer, as defined in Rule 405 of the Securities Act. Yes ☑ No ☐
Indicate by check mark if the registrant is not required to file reports pursuant to Section 13 or Section 15(d) of the Act. Yes ☐ No ☑
Indicate by check mark whether the registrant (1) has filed all reports required to be filed by Section 13 or 15(d) of the Securities Exchange Act of 1934 during the preceding 12 months (or for such shorter period that the registrant was required to file such reports), and (2) has been subject to such filing requirements for the past 90 days. Yes ☑ No ☐
Indicate by check mark whether the registrant has submitted electronically every Interactive Data File required to be submitted pursuant to Rule 405 of Regulation S-T (§232.405 of this chapter) during the preceding 12 months (or for such shorter period that the registrant was required to submit and post such files). Yes ☑ No ☐
Indicate by check mark whether the registrant is a large accelerated filer, an accelerated filer, a non-accelerated filer, smaller reporting company, or an emerging growth company. See the definitions of “large accelerated filer,” “accelerated filer,”
“smaller reporting company,” and “emerging growth company” in Rule 12b-2 of the Exchange Act. (Check one):

Large accelerated filer | ☑ | Accelerated filer | ☐ | Non-accelerated filer | ☐ | Smaller reporting company | ☐ | Emerging Growth Company | ☐

If an emerging growth company, indicate by check mark if the registrant has elected not to use the extended transition period for complying with any new or revised financial accounting standards provided pursuant to Section 13(a) of the Exchange Act. ☐
Indicate by check mark whether the registrant has filed a report on and attestation to its management’s assessment of the effectiveness of its internal control over financial reporting under Section 404(b) of the Sarbanes-Oxley Act (15 U.S.C. 7262(b)) by the registered public accounting firm that prepared or issued its audit report. ☑
Indicate by check mark whether the registrant is a shell company (as defined in Rule 12b-2 of the Act). Yes ☐ No ☑
The aggregate market value of the registrant’s common stock held by non-affiliates as of December 31, 2021 (the last business day of the registrant’s most recently completed second fiscal quarter) was approximately $21.4 billion.
As of July 25, 2022, there were 123,163,051 shares of the registrant’s common stock outstanding.
Documents Incorporated by Reference:
Portions of the registrant’s definitive proxy statement for the 2022 Annual Meeting of Stockholders (the “Proxy Statement”), to be filed within 120 days after June 30, 2022, are incorporated by reference into Part III, Items 10 through 14 of this Annual Report on Form 10-K.

Table of Contents
THE CLOROX COMPANY
ANNUAL REPORT ON FORM 10-K
FOR THE FISCAL YEAR ENDED JUNE 30, 2022
TABLE OF CONTENTS

|  |  |  |  | Page
Part I |  | Item 1. |  | Business | 1
|  | Item 1.A. |  | Risk Factors | 7
|  | Item 1.B. |  | Unresolved Staff Comments | 22
|  | Item 2. |  | Properties | 22
|  | Item 3. |  | Legal Proceedings | 22
|  | Item 4. |  | Mine Safety Disclosures | 22
Part II |  | Item 5. |  | Market for Registrant’s Common Equity, Related Stockholder Matters and Issuer Purchases of Equity Securities | 26
|  | Item 6. |  | Reserved | 26
|  | Item 7. |  | Management’s Discussion and Analysis of Financial Condition and Results of Operations | 26
|  | Item 7.A. |  | Quantitative and Qualitative Disclosures About Market Risk | 26
|  | Item 8. |  | Financial Statements and Supplementary Data | 26
|  | Item 9. |  | Changes in and Disagreements with Accountants on Accounting and Financial Disclosure | 27
|  | Item 9.A. |  | Controls and Procedures | 27
|  | Item 9.B. |  | Other Information | 27
|  | Item 9.C. |  | Disclosure Regarding Foreign Jurisdictions that Prevent Inspections | 27
Part III |  | Item 10. |  | Directors, Executive Officers and Corporate Governance | 28
|  | Item 11. |  | Executive Compensation | 28
|  | Item 12. |  | Security Ownership of Certain Beneficial Owners and Management and Related Stockholder Matters | 28
|  | Item 13. |  | Certain Relationships and Related Transactions, and Director Independence | 28
|  | Item 14. |  | Principal Accountant Fees and Services | 28
Part IV |  | Item 15. |  | Exhibits and Financial Statement Schedules | 29
|  | Item 16. |  | Form 10-K Summary | 32
Signatures |  |  |  |  | 33

Table of Contents
PART I
This Annual Report on Form 10-K for the fiscal year ended June 30, 2022 (this Report), including the exhibits hereto and the information incorporated by reference herein, contains “forward-looking statements” within the meaning of Section 27A of the Securities Act of 1933, as amended (the Securities Act), and Section 21E of the Securities Exchange Act of 1934, as amended (the Exchange Act), including, among others, statements related to the expected or potential impact of the novel coronavirus (COVID-19) pandemic, and the related responses of governments, consumers, customers, suppliers, employees and the Company, on our business, operations, employees, financial condition and results of operations, and any such forward-looking statements, whether concerning the COVID-19 pandemic or otherwise, involve risks, assumptions and uncertainties. Except for historical information, statements about future volumes, sales, organic sales growth, foreign currencies, costs, cost savings, margins, earnings, earnings per share, diluted earnings per share, foreign currency exchange rates, tax rates, cash flows, plans, objectives, expectations, growth or profitability are forward-looking statements based on management’s estimates, beliefs, assumptions and projections. Words such as “could,” “may,” “expects,” “anticipates,” “targets,” “goals,” “projects,” “intends,” “plans,” “believes,” “seeks,” “estimates,” “will,” “predicts” and variations on such words, and similar expressions that reflect our current views with respect to future events and operational, economic and financial performance, are intended to identify such forward-looking statements. These forward-looking statements are only predictions, subject to risks and uncertainties, and actual results could differ materially from those discussed below. Important factors that could affect performance and cause results to differ materially from management’s expectations are described in the sections entitled “Risk Factors” and “Management’s Discussion and Analysis of Financial Condition and Results of Operations” in this Report, as updated from time to time in the Company’s U.S. Securities and Exchange Commission (SEC) filings.
The Company’s forward-looking statements in this Report are based on management’s current views, beliefs, assumptions and expectations regarding future events and speak only as of the date of this Report. The Company undertakes no obligation to publicly update or revise any forward-looking statements, whether as a result of new information, future events or otherwise, except as required by the federal securities laws.
In this Report, unless the context requires otherwise, the terms “the Company,” “Clorox,” “we,” “us” and “our” refer to The Clorox Company and its subsidiaries.
ITEM 1. BUSINESS
Overview of Business
The Clorox Company is a leading multinational manufacturer and marketer of consumer and professional products with fiscal year 2022 net sales of $7.1 billion and about 9,000 employees worldwide as of June 30, 2022. Its products are sold primarily through mass retailers; grocery outlets; warehouse clubs; dollar stores; home hardware centers; drug, pet and military stores; third-party and owned e-commerce channels; and distributors. Clorox markets some of the most trusted and recognized consumer brand names, including its namesake bleach and cleaning products; Pine-Sol® cleaners; Liquid-Plumr® clog removers; Poett® home care products; Fresh Step® cat litter; Glad® bags and wraps; Kingsford® grilling products; Hidden Valley® dressings, dips, seasonings and sauces; Brita® water-filtration products; Burt’s Bees® natural personal care products; and RenewLife®, Rainbow Light®, Natural Vitality® and NeoCell® vitamins, minerals and supplements. The Company also markets industry-leading products and technologies for professional customers, including those sold under the CloroxPro™ and Clorox Healthcare® brand names. About 80% of the Company’s sales are generated from brands that hold the No. 1 or No. 2 market share positions in their categories. The Company was founded in Oakland, California, in 1913 and is incorporated in Delaware.
Clorox’s IGNITE strategy accelerates innovation in key areas to drive growth and deliver value for both the Company's shareholders and society. Specifically, IGNITE focuses on four strategic choices to sustain long-term, profitable growth: Fuel Growth, Innovate Experiences, Reimagine Work and Evolve Portfolio. Integrated goals for environmental, social and governance (ESG) performance are focused in the areas of Healthy Lives, Clean World and Thriving Communities.
Business Performance
In fiscal year 2022, the effects of the on-going COVID-19 pandemic continued to cause economic and societal disruptions as well as on-going uncertainties. In addition, supply chain challenges and, more recently, the conflict in Ukraine, contributed to rising cost inflation and ongoing uncertainties in the marketplace.
In fiscal year 2022, the Company's net sales decreased 3% and diluted net earnings per share (EPS) decreased 33% as compared to the year-ago period when there was elevated demand for essential household products, especially cleaning and disinfecting products, as a result of COVID-19. Other conditions factoring into the dynamic environment included ongoing uncertainty
1

Table of Contents
related to the global pandemic, persistently high manufacturing and logistics costs as well as commodity costs and the conflict in Ukraine, which further exacerbated supply chain challenges.
Clorox continued its longtime commitment to providing value to stockholders through regular dividends. During fiscal year 2022, the Company paid $571 million in dividends to stockholders. In July 2022, Clorox announced an increase of 2% in its quarterly dividend.
Guided by its IGNITE strategy, the Company remained focused on making significant investments in its strong brands and strategic digital capabilities to drive long-term value creation. These investments were made to support category growth and market share improvements. For example, new products, including Clorox® disinfecting mists; Clorox multipurpose cleaner concentrate; Glad® ForceFlexPlus trash bags in Cherry Blossom scent; Glad ForceFlex Plus with Clorox trash bags in Eucalyptus and Peppermint scent; Glad compostable drawstring bags (Canada); Glad to Be Green 50% ocean bound plastic recycled trash bags (Australia); Fresh Step® Outstretch cat litter; Kingsford® Signature Flavors charcoal, pellets and flavor boosters for charcoal and pellet grills; and Neocell® collagen powders and gummies, were launched in more than 25 categories in fiscal year 2022.
As announced in August 2021, a significant long-term investment in digital capabilities and productivity enhancements will continue to shape the Company’s outlook for fiscal year 2023 and beyond. Clorox investing approximately $500 million over five years beginning in fiscal year 2022 on these operating and capital expenditures. This investment includes replacement of the Company's enterprise resource planning system and transitioning to a cloud-based platform as well as the implementation of a suite of other digital technologies. This investment will generate efficiencies and better position Clorox in supply chain, digital commerce, innovation, brand building and more over the long term.
In international markets, the Company delivered sales growth in fiscal year 2022 behind ongoing consumer demand for cleaning and disinfecting products, as well as other household essentials including cat litter, bags and wraps and water-filtration products. The Company’s international business continues to play an important strategic role, with No. 1 and No. 2 brands in the majority of categories and countries where it operates.
Clorox continued to make progress on its ESG goals, which are integrated into the IGNITE strategy and throughout the business. Notably, to advance its Clean World pillar, the Company created an internal roadmap for its net zero and science-based targets, including engaging key business units and activating a plan to engage top suppliers to reduce emissions. Additionally, a second 12-year virtual power purchase agreement was announced, continuing Clorox’s commitment to 100% renewable electricity for its U.S. and Canadian operations. Efforts to reduce packaging waste advanced also, including internal initiatives to deliver more recycle-ready materials and address post-consumer recycled content material cost and availability as well as influence ongoing dialogue with the recycling industry through Clorox’s membership in the U.S. Plastics Pact. In support of its Thriving Communities pillar, this year the Company launched an environmental justice initiative to provide better access to green spaces for underserved communities. Through the Healthy Parks Project, the foundation plans to invest in community parks in support of the Company's purpose and ESG focus on the interconnectedness of environmental and social sustainability.
The Company has been broadly recognized for its corporate responsibility efforts. Those recognitions include the Human Rights Campaign Foundation’s Corporate Equality Index 2022 as one of the Best Places to Work for LGBTQ+ Equality; the 2022 Bloomberg Gender-Equality Index, which tracks the performance of public companies committed to transparency in gender-data reporting; and Barron’s 100 Most Sustainable U.S. Companies list.
In fiscal year 2023, the Company anticipates ongoing challenges that may impact its sales and margins, including continued uncertainty related to the COVID-19 pandemic, persistently high manufacturing and logistics and commodity costs, continued effects from the conflict in Ukraine, evolving consumer behaviors, high levels of competition in select categories, a more competitive and evolving retail environment, changes in foreign currency exchange rates and an uncertain macroeconomic environment in the U.S. and in many international markets.
As announced in August 2022, the Company will be implementing a streamlined operating model beginning in the first quarter of fiscal year 2023. As a result, the Company expects to incur restructuring costs, primarily employee-related costs, as well as associated implementation and other costs, together totaling approximately $75 to $100 million during fiscal years 2023 and 2024, with approximately $35 million to be recognized in fiscal year 2023.
For additional information on recent business developments, see “Management’s Discussion and Analysis of Financial Condition and Results of Operations,” in Exhibit 99.1, incorporated herein by reference.
2

Table of Contents
Financial Information About Operating Segments and Principal Products
The Company operates through strategic business units (SBUs) that are also the Company’s operating segments. These SBUs are then aggregated into four reportable segments: Health and Wellness, Household, Lifestyle and International. These four reportable segments consist of the following:
•Health and Wellness consists of cleaning products, professional products and vitamins, minerals and supplements mainly marketed and sold in the U.S. Products within this segment include cleaning products such as laundry additives and home care products, primarily under the Clorox, Clorox2, Scentiva, Pine-Sol, Liquid-Plumr, Tilex and Formula 409 brands; professional cleaning and disinfecting products under the CloroxPro and Clorox Healthcare brands; professional food service products under the Hidden Valley brand; and vitamins, minerals and supplements under the RenewLife, Natural Vitality, NeoCell and Rainbow Light brands.
•Household consists of bags and wraps, grilling products and cat litter marketed and sold in the U.S. Products within this segment include bags and wraps under the Glad brand; grilling products under the Kingsford brand; and cat litter primarily under the Fresh Step and Scoop Away brands.
•Lifestyle consists of food, natural personal care products and water-filtration products marketed and sold in the U.S. Products within this segment include dressings, dips, seasonings and sauces, primarily under the Hidden Valley brand; natural personal care products under the Burt’s Bees brand; and water-filtration products under the Brita brand.
•International consists of products sold outside the U.S. Products within this segment include laundry additives; home care products; water-filtration products; digestive health products; grilling products; cat litter; food; bags and wraps; natural personal care products; and professional cleaning and disinfecting products marketed primarily under the Clorox, Ayudin, Clorinda, Poett, Pine-Sol, Glad, Brita, RenewLife, Ever Clean and Burt’s Bees brands.
The Company’s products are marketed and sold globally. The following table provides the Company’s global product lines, which were sold in the U.S. (including products sold in the Professional Products SBU) and internationally, that accounted for 10% or more of consolidated net sales for the fiscal years ended June 30:

| 2022 |  | 2021 |  | 2020
Cleaning products | 42 | % |  | 43 | % |  | 43 | %
Bags and wraps | 16 | % |  | 14 | % |  | 15 | %
Food products | 11 | % |  | 10 | % |  | 10 | %

Principal Markets and Methods of Distribution
In the U.S., most of the Company’s products are nationally advertised and sold to mass retailers, grocery outlets, warehouse clubs, dollar stores, home hardware centers, military stores and other retail outlets primarily through a direct sales force; to grocery stores and grocery wholesalers primarily through a combination of direct sales teams and a network of brokers; and through e-commerce retailers. The Company also sells many of its products through alternative retail channels. Some brands are sold using the direct-to-consumer model. The Company sells institutional, janitorial, food-service and healthcare products through a direct sales force and a network of brokers to distributors and redistributors. Outside the U.S., the Company sells products to the retail trade through subsidiaries, licensees, distributors and joint-venture arrangements with local partners.
Sources and Availability of Raw Materials
The Company purchases raw materials from numerous unaffiliated U.S. and international suppliers, some of which are sole source or single-source suppliers. Interruptions in the delivery of these materials could adversely impact the Company. Key raw materials used by the Company include resin, non-woven fabrics for wipes products, sodium hypochlorite, corrugated cardboard, soybean oil, solvent, derivatives of amines and other chemicals and agricultural commodities. While sufficient raw materials were generally available during fiscal year 2022, supply constraints and commodity costs increases for certain raw materials and finished goods were experienced. This is due to supply chain disruptions combined with increased demand as the economy re-opened as the world moves into a new phase of the pandemic as well as unfavorable geopolitical and weather events experienced. The Company expects continued volatility and increased cost pressures in both commodities and transportation to continue in fiscal year 2023.
The Company generally utilizes supply contracts to help ensure availability and a number of forward-purchase contracts to help reduce the volatility of the pricing of raw materials needed in its operations. However, the Company is highly exposed to changes in the prices of commodities and transportation used in manufacturing and shipping of its products. For further information regarding the impact of changes in commodity prices, see “Management’s Discussion and Analysis of Financial Condition and Results of Operations” in Exhibit 99.1, “Risk Factors – Volatility and increases in the costs of raw materials,
3

Table of Contents
energy, transportation, labor and other necessary supplies or services have negatively impacted, and may continue to negatively impact, the Company’s net earnings and cash flow” and “Risk Factors – Supply chain issues can result in product shortages or disruptions to the Company’s business” in Item 1.A.
Patents and Trademarks
Most of the Company’s brand name consumer products are protected by registered trademarks. The Company’s brand names and trademarks are highly important to its business, and the Company vigorously protects its trademarks from apparent infringements. Maintenance of brand equity value is critical to the Company’s success. The Company’s patent rights are also material to its business and are asserted, where appropriate, against apparent infringements.
Seasonality
Most sales of the Company’s grilling products occur during the months of March through September each calendar year. The volume and sales of grilling products may be affected by weather conditions. Our disinfecting products may be subject to higher levels of seasonality given ongoing pandemic/endemic surges.
Customers
Net sales to the Company’s largest customer, Walmart Stores, Inc. and its affiliates, were 25% of consolidated net sales for each of the fiscal years ended June 30, 2022, 2021 and 2020, and occurred across all of the Company’s reportable segments. No other individual customer accounted for 10% or more of the Company’s consolidated net sales in any of these fiscal years. The Company’s five largest customers accounted for nearly half of the Company’s consolidated net sales for each of the fiscal years 2022, 2021 and 2020.
Competition
The markets for consumer products are highly competitive. The Company’s products compete with other nationally advertised brands and with “private label” brands within each category. Competition comes from similar and alternative products, some of which are produced and marketed by major multinational or national companies having financial resources greater than those of the Company. In addition, the Company faces competition from retailers, including club stores, grocery stores, drugstores, dollar stores, mass merchandisers, e-commerce retailers and subscription services. Furthermore, heightened competitive activity is expected as inflation continues to increase, consumers experience reduced purchasing power and the Company implements pricing to offset higher costs. The Company’s products generally compete on the basis of product performance, brand reputation and recognition, image and price. A newly introduced consumer product (whether improved or newly developed) usually encounters intense competition requiring substantial expenditures for advertising, sales promotion and trade merchandising support. If a product gains consumer acceptance, it typically requires continued advertising and promotional support and ongoing product innovation to maintain its relative market position. For further information regarding the intense competition the Company faces, see “Risk Factors – The Company faces intense competition in its markets, which could lead to reduced net sales, net earnings and cash flow” in Item 1.A.
Environmental Matters
For information regarding noncapital expenditures related to environmental matters, see the discussions below under “Risk Factors – Environmental matters create potential liabilities that could adversely affect the Company’s financial condition and results of operations” in Item 1.A. No material capital expenditures relating to environmental compliance are presently anticipated.
HUMAN CAPITAL MANAGEMENT
Purpose and Values
The Clorox Company is led by our purpose to champion people to be well and thrive every single day – from our employees to the consumers and communities we serve around the world.
Launched in 2019, the IGNITE strategy accelerates innovation in key areas to drive growth and deliver value through a focus on four strategic choices over the long term: Fuel Growth, Innovate Experiences, Reimagine Work and Evolve Portfolio. Goals for ESG are embedded in IGNITE, and we approach our ESG work through our pillars of Healthy Lives, Clean World and Thriving Communities, all underpinned by strong governance. Our values are the foundation for everything we do and are essential to our success: Do the Right Thing, Put People at the Center, and Play to Win.
4

Table of Contents
Employees
As of June 30, 2022, the Company employed about 9,000 people worldwide, with 72% in the U.S. and 28% working in our international locations. Our U.S. workforce includes 49% nonproduction employees and 51% production employees, while our international workforce includes 56% nonproduction employees and 44% production employees.
Inclusion and Diversity
People are critical to our efforts to drive growth and deliver value for shareholders. One of the ways we put people at the center is by continuing to work toward a more inclusive and diverse workplace because we believe diverse backgrounds, experiences and perspectives create stronger teams, unlock more innovation and – ultimately – contribute to greater success both individually and collectively.
Our Inclusion and Diversity (I&D) strategy development and execution is led by our Chief Diversity and Social Impact Officer, who joined the Company in July 2022, is a member of the Clorox Executive Committee and reports to our Chief Executive Officer. Our I&D Committee is chaired by our Chief Operating Officer. I&D metrics are included in the corporate scorecard regularly reviewed by the board, reflecting our view that advancing I&D is essential to our long-term business success. Many employees and task forces across different communities, functions and geographies support this work.
We annually conduct pay equity analyses as part of our regular compensation cycle for our non-production teammates, partnering with a third-party labor economist to review potential discrepancies. Our goal is for each employee to be compensated fairly, irrespective of race, ethnicity and gender.
Over a dozen employee resource groups (ERGs) reflect the diverse demographics of our workforce and are intended to create a sense of belonging for our employees through community, education and awareness, which helps attract and retain diverse talent and deepen our understanding of our diverse consumer base. We believe that these ERGs also create value for our business by amplifying both employee and consumer voices.
In fiscal year 2022, we were included in Forbes’ 2022 America’s Best Employers for Diversity list, ranking eighth out of 500 companies. Clorox was also included in the 2022 Bloomberg Gender Equality Index, which measures gender equality across the pillars of female leadership and talent pipeline, equal pay and gender pay parity, inclusive culture, sexual harassment policies and pro-women brand.
Employee diversity. As of June 30, 2022, people of color 1 represented 42% of our total U.S. population of employees, 17% of U.S. senior executives, 32% of U.S. managers, 44% of other U.S. nonproduction employees and 44% of U.S. production employees. Women made up 36% of our global population, 46% of global senior executives, 47% of global managers, 56% of other global nonproduction employees and 19% of global production employees.
Board and leadership diversity. Clorox’s first female CEO, Linda Rendle, was promoted to lead the Company in September 2020. As of June 30, 2022, the Clorox Executive Committee was composed of 43% women and 14% people of color. Additionally, 46% of our board is female and 31% are people of color, with our Nominating, Governance and Corporate Responsibility Committee (NGCRC) and our Audit Committee chaired by people of color. Our NGCRC chair is also a woman.
1 Management defines people of color (POC) as any race that is not White (Asian; Black; Latino; Native American; Native Hawaiian; or two or more races). Gender and ethnicity information is provided by employees on a voluntary, self-identification basis. To the extent that the employees do not voluntarily report, the data would not be included in the respective calculation.
5

Table of Contents
Hiring and Development
We look to attract and retain the best talent to deliver against our strategy and commitments. We prioritize career growth and leadership development because growing our talent and building our capabilities supports retention and helps us establish a strong foundation for long-term success. Our investments include a suite of training and education for people managers to help them become effective coaches and leaders, mentoring programs and initiatives to help build a pipeline of diverse talent, our summer internship, co-op and full-time equivalent (FTE) rotational programs for college hires. In addition, we partner with our ERGs and establish partnerships with external organizations that work to advance equity and opportunity for the communities they represent. We also conduct a robust talent review and leader succession planning process to ensure a strong pipeline for key roles.
As the pandemic evolves and we move to new ways of working, we have anchored to a set of core beliefs in making decisions: there’s value in being together - some of the time; the future of work is hybrid; and the Clorox experience must be good for our people and our business. These beliefs influenced the design of the hybrid work experience we implemented in fiscal year 2022.
Employee Engagement and Retention
We employ an ongoing listening strategy, which includes both annual and more frequent pulse surveys. We also survey our employees on their engagement to gauge their perception of the Company as a place to work as well as their views of leadership, understanding of our IGNITE strategy, and sense of inclusion. In fiscal year 2022, our employee engagement was 82%, which was in line with the 50 th percentile for Fortune 500 and industry benchmarks 2. Our engagement score declined by 5% as compared to fiscal year 2021, which is similar to engagement and retention trends across our and other industries. The employee engagement surveys are part of our continuous improvement mindset around building a culture at Clorox that is both engaging and aligned to our purpose, values and IGNITE strategy.Like many companies, we have experienced elevated turnover in fiscal year 2022. In order to retain top talent, we regularly assess retention risk and employee sentiment through the employee engagement survey and other channels and develop and execute related action plans.
Employee Safety and Well-Being
As a health and wellness company, the Company takes a holistic approach to caring for our employees, with benefits and programs designed to support physical, mental and financial well-being.
Our focus on safety is an example of how we put people at the center. We support that pledge through a combination of education, training and related policies, while also operating in compliance with applicable regulations, including Occupational Safety and Health Administration (OSHA) guidelines in the U.S. In fiscal year 2022, the Company’s reportable incident rate (RIR) was 0.56. This was significantly lower than the 3.1 average RIR for goods-producing manufacturing companies in 2020, which is the latest available data from the U.S. Bureau of Labor Statistics 3.
Recognizing the prolonged effects of the pandemic, the Company has increasingly focused on supporting our people’s mental health. We expanded our sick time policy to explicitly include mental well-being and launched a partnership with a new global Employee Assistance Program partner that enables coverage across all regions. We continue to provide parents with support such as paid parental leave, adoption resources and subsidized childcare, and have announced we will offer enhanced family-forming benefits beginning in January 2023.
To support our people’s financial well-being, the Company provides competitive compensation – including short- and long-term incentives – to attract and retain top talent. In addition, we support our employees’ retirement readiness by offering third-party financial planning services and a 401(k) plan that is above market relative to the industry average, with the Company contributing up to 10% of an employee’s annual salary.
Societal Well-Being
In fiscal year 2022 The Clorox Company Foundation created a signature theme of health security, based on the belief that health and wellness is a basic human right. The foundation now focuses on programs in three areas to address this signature theme: community wellness, disease prevention and disaster relief and preparedness. Using this framework, our foundation further brings our purpose to life as we champion people to be well and thrive every single day.
2 Employee engagement surveys may vary across companies on a year-to-year basis.
3 Our Fiscal year 2022 RIR of 0.56 means that for every 100 full-time equivalent Clorox employees globally we averaged less than one reportable incident during the past year. The criteria used to determine RIR follows the U.S. Department of Labor’s OSHA guidelines and is applied globally.
6

Table of Contents
Additionally, we provide cash grants (including matching employee donations) and product donations while also implementing cause marketing programs to support our communities on important matters including health and safety, education and racial justice.
Finally, to activate the foundation’s new community wellness focus, the Company launched the Healthy Parks Project to address environmental justice and provide better access to green spaces in underserved communities. In the project's first year, the Company will support parks organizations where it has large employee bases – starting in Oakland, California – benefiting the health of local communities.
Available Information
The Company’s Annual Report on Form 10-K, Quarterly Reports on Form 10-Q and Current Reports on Form 8-K and amendments to those reports filed or furnished pursuant to Sections 13(a) or 15(d) of the Exchange Act are available on the Company’s website, free of charge, as soon as reasonably practicable after the reports are electronically filed with or furnished to the SEC. These reports are available at TheCloroxCompany.com under Investors/Financial Information/SEC Filings. Additionally, the Company routinely posts additional important information, including press releases, on its website and recognizes its website as a channel of distribution to reach public investors and as a means of disclosing material non-public information for complying with disclosure obligations under Regulation FD. Accordingly, investors should monitor our website in addition to our SEC filings and public webcasts. These items are available at TheCloroxCompany.com under Investors/Investor News and Events.
Information relating to corporate governance at Clorox, including the Company's Code of Conduct, the Clorox Company Board of Directors Governance Guidelines and Board Committee charters for the Management Development and Compensation Committee, the Audit Committee, and the Nominating, Governance and Corporate Responsibility Committee, is available at TheCloroxCompany.com under Who We Are/Corporate Governance or https://www.thecloroxcompany.com/who-we-are/corporate-governance/. The Company will provide any of the foregoing information without charge upon written request to Corporate Communications, The Clorox Company, 1221 Broadway, Oakland, CA 94612-1888. The information contained on the Company's website is not included as a part of, or incorporated by reference into, this Report.
ITEM 1.A. RISK FACTORS
The risks and uncertainties set forth below, as well as other factors described elsewhere in this Report or in other filings by the Company with the SEC, could adversely affect the Company’s business, financial condition and results of operations. Additional risks and uncertainties that are not currently known to the Company or that are not currently believed by the Company to be material may also harm the Company’s business, financial condition and results of operations.
Business and Industry Risks
The changing retail environment and changing consumer preferences could adversely affect the Company’s business, financial condition and results of operations.
The Company’s sales are largely concentrated in the traditional retail grocery, mass retail outlet, warehouse club and dollar store channels, in addition to e-commerce channels. As the COVID-19 pandemic conditions change, we cannot predict how the retail environment will evolve or whether there will continue to be a greater consumer emphasis on health and wellness. Alternative retail channels, including hard discounters, subscription services and buying clubs, have become and may continue to be more prevalent and popular than traditional retailers. In addition, a growing number of alternative sales channels and business models, such as niche brands, native online brands, private label and store brands, direct-to-consumer brands and channels and discounter channels, have emerged in the markets we serve driven, in part, by the COVID-19 pandemic. In particular, the growing presence of, and increasing sales through, e-commerce retailers have affected, and may continue to affect, consumer behavior or preferences (as consumers increasingly shop online and via mobile and social applications) and market dynamics, including any pricing pressures for consumer goods as retailers face added costs to build their e-commerce capacity. These trends have been magnified due to the COVID-19 pandemic in many of our geographies. Further, consumer preferences continue to evolve due to a number of factors, including fragmentation of the consumer market and changes in consumer demographics, which includes the aging of the general population and the emergence of millennial and younger generations who have different spending, consumption and purchasing habits; evolving consumer concerns or perceptions regarding ESG practices of manufacturers, including the sourcing and sustainability of packaging materials, such as single-use plastics; a growing demand for natural or organic products and ingredients; evolving consumer concerns or perceptions (whether accurate or inaccurate) regarding the effects of ingredients or substances present in certain consumer products; changing consumer sentiment toward non-local products or sources; and changing perceptions of environmental impacts (including packaging, energy and water use and waste management). If we are not successful in continuing to adapt to changing consumer preferences and market dynamics or expanding sales through e-commerce retailers or alternative retail channels, our
7

Table of Contents
business, financial condition and results of operations may be negatively impacted. In addition, e-commerce and alternative retail channels may create significant pricing pressures for consumer goods, presenting additional challenges to increasing prices in response to commodity or other cost increases in all of the channels into which the Company sells. If these e-commerce and alternative retail channels were to take significant market share away from traditional retailers and/or the Company is not successful in these channels or business models, our margins and results of operations may be materially and negatively impacted.
Sales growth objectives may be difficult to achieve, the Company may not be able to successfully implement price increases, and market and category declines and changes to the Company’s product and geographic mix may adversely impact the Company’s financial condition and results of operations.
A large percentage of the Company’s revenues comes from mature markets that are subject to high levels of competition. During fiscal year 2022, 84% of the Company’s net sales were attributable to U.S. markets, including U.S. territories. The Company’s ability to achieve sales growth depends on its ability to drive growth through innovation, including as part of its IGNITE Strategy, expand into new products and categories, channels and countries, invest in its established brands and enhanced merchandising, grow categories with retailers and capture market share from competitors. The Company’s ability to achieve sales growth also depends on foreign currency fluctuations. A weakening of foreign currencies in which sales are generated relative to the Company’s reporting currency (U.S. dollars) would decrease net sales. The Company has implemented price increases and may implement additional price increases in the future, which may slow sales growth or create volume declines in the short term as customers and consumers adjust to these price increases. In addition, our competitors may or may not take competitive actions, which may lead to sales declines and loss of market share. If the Company is unable to increase market share in existing product lines, develop product innovations, undertake sales, marketing and advertising initiatives that grow its product categories and/or develop, acquire or successfully launch new products or brands, it may not achieve its sales growth objectives. Furthermore, a general decline in the markets for certain product categories has had and may in the future have a negative impact on the Company’s financial condition and results of operations. In addition, changes to the mix of products that the Company sells, as well as the mix of countries in which its products are sold, may adversely impact the Company’s net sales, profitability and cash flow.
The ongoing COVID-19 pandemic and related impacts has had, and could continue to have, an adverse effect on the Company’s business, financial condition and results of operations.
The ongoing COVID-19 pandemic, including the emergence of variants for which vaccines may not be effective, may negatively affect our business by causing or contributing to, among other things:
• Significant disruptions in our business operations and in the ability of significant third-party vendors, manufacturing and other business or commercial partners, including customers, to meet their obligations to us;
• Significant decrease or volatility in sales of or demand for our primary products due to, among other things: any decreased demand for cleaning and disinfecting products as COVID-19 restrictions continue to lift and we transition from a pandemic to endemic state; closure or reduced operating hours of our key customers; consumer inability to purchase our products due to personal illness or government implemented restrictions and any resulting changes in consumer preference; and reduced availability of certain products as we prioritize the production of other products due to changes in demand;
• Worldwide, regional and local adverse economic and financial market conditions, including increased risk of inflation; fluctuations in commodities, packaging, transportation and other input costs; increased unemployment; decreased disposable income; declining consumer confidence; or economic slowdowns or recessions in any of our major markets, all of which could impact the manufacturing operations of the Company or our third-party partners;
• Significant U.S. or international governmental actions, or other limitations or restrictions, including restrictions on the ability of our employees, suppliers, customers or third-party partners to travel or perform necessary business functions or our ability to manufacture, ship, distribute, market or sell our products; and
• Adverse impacts on our supply chain, including manufacturing by the Company or third-party partners, due to raw material, packaging or other supply shortages, labor shortages or reduced availability of air or other commercial transport, port congestion and closures. Although we are unable to predict the impact on our ability to source materials in the future, we expect these and other supply chain pressures to continue into the coming year.
In addition, sustained labor shortages or increased turnover rates within our employee base, caused by COVID-19 or as a result of general macroeconomic factors, could lead to increased costs, such as increased wage rates to attract and retain employees, and could negatively affect our ability to efficiently operate our manufacturing and distribution facilities and overall business. The actions we take in response to any improvements in conditions related to COVID-19, such as our return-to-office plans,
8

Table of Contents
may also vary widely by geography and will likely be made with incomplete information, and may prove to be premature, incorrect or insufficient, and could have a material, adverse impact on our business and results of operations.
Furthermore, we have experienced and could continue to experience higher costs in certain areas as a result of COVID-19, which may continue, increase or become necessary in these or other areas. Even as efforts to contain the pandemic have made progress and some restrictions have relaxed, new variants of the virus are causing additional outbreaks. The extent of COVID-19’s effect on our operational and financial performance in the future will depend on future developments, including the duration, spread and intensity of the pandemic, our continued ability to manufacture and distribute our products, any future government actions affecting consumers, our business operations, including any vaccine mandates, and the economy generally, changing economic conditions and any resulting inflationary impacts, as well as timing and effectiveness of global vaccines, all of which are uncertain and difficult to predict considering the rapidly evolving landscape. Such impacts could materially adversely affect the Company’s business, financial condition and results of operations.
The Company faces intense competition in its markets, which could lead to reduced net sales, net earnings and cash flow.
The Company faces intense competition from consumer product companies both in the U.S. and in its international markets. Most of the Company’s products compete with other widely advertised, promoted and merchandised brands within each product category. The Company also faces competition from retailers, including club stores, grocery stores, drugstores, dollar stores, mass merchandisers, e-commerce retailers and subscription services, which are increasingly offering “private label” brands that are typically sold at lower prices and compete with the Company’s products in certain categories. Increased purchases of “private label” products or other lower cost priced brands could negatively impact net sales of the Company’s higher-margin products or there could be a shift in product mix to lower-margin offerings, especially at a time of rising inflation, and this would negatively impact our margins. The Company’s products generally compete on the basis of product performance, brand reputation and recognition, image and price. Advertising, promotion, merchandising and packaging also have significant impacts on consumer purchasing decisions, and the Company is increasingly using digital media marketing and promotional programs to reach consumers. A newly introduced consumer product (whether improved or newly developed) usually encounters intense competition requiring substantial expenditures for advertising, sales promotion and trade merchandising. If a product gains consumer acceptance, it typically requires continued advertising, promotional support and product innovations to maintain its relative market position. If the Company’s advertising, marketing and promotional programs, including its use of digital and social media to reach consumers, are not effective or adequate, the Company’s net sales may be negatively impacted.
Some of the Company’s competitors are larger than the Company and have greater financial resources. These competitors may be able to spend more aggressively on advertising and promotional activities, introduce competing products more quickly and respond more effectively to changing business and economic conditions than the Company can. Heightened competitive activity from strong local competitors, other large multinational companies, and new entrants into the market may result in more aggressive product claims and marketing challenges, increased promotional spending and geographic expansion, and marketing of new disinfecting products. Furthermore, the Company’s competitors may attempt to gain market share by offering products at prices at or below those typically offered by the Company. Competitive activity may require the Company to increase its spending on advertising and promotions and/or reduce prices, which could lead to reduced sales, margins and/or net earnings.
Unfavorable general economic and political conditions beyond our control could negatively impact our financial results.
General economic factors that are beyond our control have materially adversely affected, and could continue to materially adversely affect, our business, results of operations, financial condition and liquidity. These factors include, but are not limited to, recent supply chain disruptions, labor shortages, wage pressures, rising inflation and potential economic slowdown or recession, as well as housing markets, consumer credit availability, consumer debt levels, fuel and energy costs (for example, the price of gasoline), interest rates, tax rates and policy, unemployment trends, the impact of natural disasters, pandemics, civil disturbances and terrorist activities, foreign currency exchange rate fluctuations, conditions affecting the retail environment for products sold by us and other matters that influence consumer spending and preferences.
Other financial uncertainties in our major markets and unstable geopolitical conditions in certain markets, including civil unrest and governmental changes, could undermine global consumer confidence and reduce consumers’ purchasing power, thereby reducing demand for our products. Restrictions on our ability to transfer earnings or capital across borders, price controls, limitations on profits, retaliatory tariffs, import authorization requirements and other restrictions on business activities which have been or may be imposed or expanded as a result of political and economic instability, deterioration of economic relations between countries or otherwise, could impact our profitability. In addition, U.S. trade sanctions against countries designated by the U.S. government as state sponsors of terrorism and/or financial institutions accepting transactions for commerce within such countries could increase significantly, which could make it impossible for us to continue to make sales to customers in such countries. The imposition of retaliatory sanctions against U.S. multinational corporations by countries that are or may become
9

Table of Contents
subject to U.S. trade sanctions, or the delisting of our branded products by retailers in various countries in reaction to U.S. trade sanctions or other governmental action or policy, could also negatively affect our business.
In February 2022, Russia invaded Ukraine. Although we recently suspended our cat litter distribution business in Russia (amounting to fiscal year 2021 net sales of $7 million) in March 2022, we have experienced, and expect to continue to experience, the indirect impacts of the conflict in Ukraine, including increases in the cost of raw and packaging materials and commodities (including the price of oil), supply chain and logistics challenges and foreign currency volatility, and it is not possible to predict the broader or longer-term consequences of this conflict or the sanctions imposed to date.
Dependence on key customers could adversely affect the Company’s business, financial condition and results of operations.
A limited number of customers account for a large percentage of the Company’s net sales. Net sales to the Company’s largest customer, Walmart Stores, Inc. and its affiliates, were 25% of consolidated net sales for the fiscal years ended June 30, 2022, 2021 and 2020, and occurred across all of the Company’s reportable segments. The Company’s five largest customers accounted for nearly half of the Company’s consolidated net sales for each of the fiscal years 2022, 2021, and 2020, and a significant portion of the Company’s future revenues may continue to be derived from a small number of customers. As a result, changes in the strategies of the Company’s largest customers, including a reduction in the number of brands they carry, a shift of shelf space to “private label” or competitors’ products or a decision to lower pricing of consumer products, including branded products, may harm the Company’s net sales or margins, and reduce the ability of the Company to offer new, innovative products to consumers. In addition, the use of the latest technology by our customers regarding pricing may lead to category pricing pressures. Consistent with the ongoing variability in information technology systems industry-wide, our information technology platforms may not be fully compatible at all times with those used by our customers. Therefore, it may or may not have an impact on our ability to respond to customer demands specific to data or technology. Furthermore, any loss of a key customer or a significant reduction in net sales to a key customer, even if such loss or reduction relates to a key customer of a business unit of the Company, could have a material adverse effect on the Company’s business, financial condition and results of operations.
The Company’s business is based primarily upon individual sales orders, and the Company typically does not enter into long-term contracts with its customers. Accordingly, customers could reduce their purchasing levels or cease buying products from the Company at any time and for any reason. If the Company does not effectively respond to the demands of its customers, they could decrease their purchases from the Company, causing the Company’s net sales and net earnings to decline. Furthermore, unfavorable market conditions or competitive pressures may cause the Company’s customers to reevaluate the number and mix of brands they sell, resulting in lower purchases of the Company’s products by these customers. We regularly review the financial strength of our key customers and, where appropriate, modify customer credit limits, which may have an adverse impact on future sales.
With the growing trend towards retailer consolidation, both in the U.S. and internationally, the continued growth of e-commerce and the integration of traditional and digital operations at key retailers, we are increasingly dependent on certain retailers. This trend, which has been magnified due to the COVID-19 pandemic, has resulted in the increased size and influence of large consolidated retailers, who have in the past changed, and may in the future change, their business strategies, demand lower pricing, or higher trade discounts or impose other burdensome requirements on product suppliers or move away from branded products to “private label”. These large consolidated companies could also exert additional competitive pressure on the Company’s other customers, which could in turn lead to such customers demanding lower pricing, higher trade discounts or special packaging or imposing other onerous requirements on the Company. If the Company ceases doing business with a significant customer or if sales of its products to a significant customer materially decrease due to customer inventory reductions or otherwise, the Company’s business, financial condition and results of operations may be harmed.
Loss of, or inability to attract, key personnel could adversely impact the Company’s business.
The Company’s success depends, in part, on its continuing ability to identify, hire, develop and retain highly qualified and diverse personnel. The labor market for these employees is very competitive, and wages and compensation costs continue to increase. Our ability to attract and retain talent has been and may continue to be impacted by challenges in the labor market, particularly in the U.S., which is experiencing wage inflation, sustained labor shortages, a shift toward remote work and the effects of COVID-19. We compete to attract talent within and outside of our industry for high demand skills that are scarce in key geographic areas such as the San Francisco Bay Area. The Company’s ability to attract or retain qualified personnel in the future has been and may continue to be impacted by the labor market. Related activities to identify, hire and onboard qualified talent at increasing compensation costs may require significant time and expense which could further adversely affect the Company’s operations and financial results. The Company’s success also depends on its ability to retain its key personnel, including its executive officers and senior management team, and to continue to implement its succession plans for senior management and other key employees. The unexpected loss or unavailability of one or more of the Company’s key leaders could disrupt its business.
10

Table of Contents
In addition, labor costs in the U.S. are rising, and our industry is experiencing a shortage of workers. Labor is one of the primary components in the cost of operating our business. If we face labor shortages and increased labor costs as a result of increased competition for employees, higher employee turnover rates, increases in employee benefits costs, or labor union organizing efforts, our operating expenses could increase and our growth and results of operations could be adversely impacted. Labor shortages, higher employee turnover rates and labor union organizing efforts could also lead to disruptions in our business. We may be unable to increase prices of our products in order to pass future increased labor costs onto our customers, in which case our margins would be negatively affected. Additionally, if we increase product prices to cover increased labor costs, the higher prices could adversely affect sales volumes.
Harm to the Company’s reputation or the reputation of one or more of its leading brands or products could have an adverse effect on the business, financial condition and results of operations.
Maintaining a strong reputation with consumers, customers and trade and other third party partners is critical to the success of the Company’s business. The Company devotes significant time and resources to training programs, relating to, among other things, ethics, compliance and product safety and quality, as well as sustainability goals, and has published ESG goals, including relating to environmental impact and sustainability and inclusion and diversity, as part of its IGNITE Strategy. Despite these efforts or if the Company is not successful in achieving its goals, provides materially inaccurate information, or receives negative publicity about the Company, including relating to product safety, quality, efficacy, ESG or similar issues, whether real or perceived, could occur. In addition, the Company’s products could face withdrawal, recall or other quality issues, which could lead to decreased demand for and reputational damage to the related brands. In particular, the Company’s dietary supplement and related products are highly dependent on consumers’ perception of the efficacy, safety and quality of our products, and may be supported by only a limited number of conclusive clinical studies. Newly published clinical studies and emerging studies could prove or allege that ingredients in our dietary supplement products or the products themselves (or similar products of other companies) are ineffective or harmful to consumers. The Company also licenses certain of its brands to third parties, and, with the increase in demand for public disinfecting and cleaning products due to the COVID-19 pandemic, the Company has increased and may continue to increase its focus on partnering with, or licensing its intellectual property to, companies in industries involving shared space, and may partner with other companies, to provide disinfecting products and cleaning education and protocols, and to leverage its related brands. Such licenses and partnerships may create additional exposure for those brands to product safety, quality, sustainability and other concerns.
Widespread use of social media and networking sites by consumers has greatly increased the accessibility and speed of dissemination of information. Negative publicity, posts or comments about the Company, its brands, its products, its marketing activities, whether accurate or inaccurate, or disclosure of non-public sensitive information about the Company, could be widely disseminated through the use of social media or in other formats. Additionally, marketing initiatives may not have the desired effect on a brand’s or product’s image. Such events, if they were to occur, could harm the Company’s image and adversely affect its business, financial condition and results of operations, as well as require resources to rebuild the Company’s reputation.
The Company may not successfully introduce new products and line extensions, or expand into adjacent categories and countries, which could adversely impact its financial condition and results of operations.
The Company’s future performance and growth depends on innovation and its ability to successfully develop or license capabilities to introduce new products, brands, line extensions and product innovations or enter into or expand into adjacent product categories, sales channels or countries. The Company’s ability to anticipate changes in consumer preferences and quickly innovate in order to adapt its products to meet changing consumer demands is essential, especially in light of the reduction in barriers for even small competitors to quickly introduce new brands and products directly to consumers that e-commerce permits. This risk is further heightened by the continued evolution of consumer needs, habits and preferences as a result of shifts in U.S. demographics, reflecting various factors including cultural and socioeconomic changes. The Company cannot be certain that it will successfully achieve its innovation goals. New product development and marketing efforts, including efforts to enter markets or product categories in which the Company has limited or no prior experience, not only incur substantial capital expenditures but also contain inherent risks. These risks include product development or launch delays, which could result in the Company not being first to market, and the failure of new products, brands and line extensions to achieve anticipated levels of market acceptance. If product introductions are not successful, costs associated with these efforts may not be fully recouped and the Company’s net earnings could be adversely affected. In addition, if sales generated by new products cause a decline in sales of the Company’s existing products, the Company’s business, financial condition and results of operations could be materially adversely affected.
11

Table of Contents
Acquisitions, new venture investments and divestitures may not be successful, which could have an adverse effect on the Company’s business, financial condition and results of operations.
In connection with the Company’s strategy, the Company expects to continue to seek acquisition, joint venture and investment opportunities. However, the Company may not be able to identify and successfully negotiate suitable strategic transactions at attractive prices. In addition, an increase in regulatory restrictions or continued market volatility could hinder the Company’s ability to execute strategic business activities including any acquisitions or investments. Furthermore, all acquisitions and investments entail numerous risks, including risks relating to the Company’s ability to:
• successfully integrate acquired companies, brands, products, technologies, systems or personnel into the Company’s existing business operations in an effective, timely and cost efficient manner;
• maintain uniform standards, controls, procedures and policies throughout acquired companies, including effective integration of acquired companies into the Company’s internal control over financial reporting;
• successfully enter categories, markets and business models in which the Company may have limited or no prior experience;
• achieve expected synergies and obtain the desired financial or strategic benefits from acquisitions within the anticipated time periods, if at all;
• achieve distribution expansion related to products, categories and markets from acquisition and retain key relationships and or personnel of acquired companies;
• identify and manage any legal or reputational risks that may predate or be associated with a transaction, which could negatively impact the Company following the consummation of such transaction; and
• manage other unanticipated problems or liabilities.
Acquired companies or operations, joint ventures or investments may not be profitable or may not achieve sales levels and profitability and cash flow expectations. Furthermore, acquisitions or ventures could also result in dilutive issuances of equity securities, the incurrence of debt, the assumption of contingent liabilities, such as those relating to advertising claims, environmental issues and litigation, negative reputational issues, an increase in expenses related to intangible assets, including trademarks and goodwill, and increased operating expenses, all of which could adversely affect the Company’s financial condition and results of operations. Future acquisitions of foreign companies or new foreign ventures would subject the Company to local regulations and could potentially lead to risks related to, among other things, increased exposure to foreign exchange rate changes, tax or labor laws, government price control, repatriation of profits and liabilities relating to the Foreign Corrupt Practices Act (“FCPA”). In addition, to the extent that the economic benefits associated with an acquisition or investment diminish in the future or the performance of an acquired company or business is less robust than expected, we may be required to record impairments of intangible assets, including trademarks and goodwill. Any impairment charges could adversely affect the Company’s financial condition and results of operations.
The Company has divested and may, in the future, divest certain assets, businesses or brands. With respect to any potential future divestiture, the Company may encounter difficulty finding potential acquirers or other divestiture options on favorable terms. Any future divestiture could affect the profitability of the Company as a result of the gains or losses on such sale of a business or brand, the loss of the operating income or sales resulting from such sale or the costs or liabilities that are not assumed by the acquirer that may negatively impact profitability and cash flow subsequent to any divestiture. The Company may also be required to recognize impairment charges or other losses as a result of a divestiture.
In addition, any potential future acquisitions, new ventures or divestitures may divert the attention of management and resources from other business priorities. The occurrence of any of these risks or uncertainties may have a material adverse effect on the Company’s business, financial condition and results of operations.
The performance of strategic alliances and other business relationships could adversely affect our business, reputation, financial condition and results of operations.
We enter into strategic alliances and other business relationships, such as relationships in connection with the co-development of products or devices, or promotion and sales relationships with companies in industries operating in public spaces. These relationships may not generate the level of sales we anticipate when entering into the relationship or may otherwise adversely impact our business, reputation, financial condition and results of operations. Furthermore, such relationships have and, in the future, could create additional exposure to litigation, investigations, disputes or other proceedings, as well as product safety, quality, sustainability and other concerns.
12

Table of Contents
Operational Risks
Volatility and increases in the costs of raw materials, energy, transportation, labor and other necessary supplies or services have negatively impacted, and may continue to negatively impact, the Company’s net earnings and cash flow.
Volatility and increases in the cost of raw materials, including resin, non-woven fabrics for wipes products, sodium hypochlorite, corrugated cardboard, soybean oil, solvent, derivatives of amines, and other chemicals and agricultural commodities, and rapid increases in the cost of energy, transportation, labor and other necessary supplies or services, have harmed, and are likely to continue to harm, the Company’s results of operations. Significant inflationary pressures have impacted our gross margin in fiscal year 2022, and we expect inflationary pressures to continue into fiscal year 2023. We have also experienced and may continue to experience disruption in our manufacturing operations and supply chain. Many of the raw materials and supplies used in the production of our products are subject to price volatility and fluctuations in availability caused by many factors, including market conditions, inflation, supplier capacity restraints, geopolitical developments (including the ongoing conflict in Ukraine), changes in supply and demand, weather conditions (including the potential effects of climate change), fire, natural disasters, growing and harvesting conditions, energy costs, health epidemics or pandemics or other contagious outbreaks (including COVID-19), labor shortages, currency fluctuations, governmental actions (including import and export requirements such as new or increased tariffs, sanctions, quotas or trade barriers), port congestions or delays, transport capacity restraints, cybersecurity incidents or other disruptions, loss or impairment of key manufacturing sites, acts of terrorism and other factors beyond our control. Certain raw materials, supplies and other goods and services have been impacted by the COVID-19 pandemic and inflationary pressures and although we are unable to predict the impact to our ability to source such materials and services in the future, we expect these supply pressures and market disruptions to continue into fiscal year 2023.
If such cost pressures occur or exceed the Company’s estimates and the Company is not able to increase the prices of its products or achieve cost savings to offset such cost increases, its margins would be harmed. In addition, even if the Company increases the prices of its products in response to increases in the cost of commodities or other cost increases, it may not be able to sustain its price increases. Sustained price increases may lead to declines in volume as competitors may not adjust their prices or customers may decide not to pay the higher prices, which could lead to sales declines and loss of market share, and the Company’s projections may not accurately predict the volume impact of price increases, which could adversely affect its business, financial condition and results of operations.
To reduce the cost volatility associated with anticipated purchases of certain commodities, the Company uses derivative instruments, including commodity futures and swaps. The extent of the Company’s derivative position at any given time depends on the Company’s assessment of the markets for these commodities, the cost volatility in the markets and the cost of the derivative instruments. Many of the commodities used by the Company in its products do not have actively traded derivative instruments. If the Company does not or is unable to take a derivative position and costs subsequently increase, or if it executes a position and costs subsequently decrease, the Company’s costs may be greater than anticipated or higher than its competitors’ costs and the Company’s financial results could be adversely affected. For further information regarding the Company’s use of derivative instruments, see “Management’s Discussion and Analysis of Financial Condition and Results of Operations” in Exhibit 99.1.
Supply chain issues can result in product shortages or disruptions to the Company’s business.
The Company has a complex global network of suppliers that has expanded to meet increased customer demand and may, in the future, further evolve in response to market conditions. The Company also relies on a number of sole-source and single-source suppliers for certain commodities and raw material inputs, including packaging, product components, finished products and other necessary supplies. The Company has experienced and could continue to experience material disruptions in production and other supply chain issues, including as a result of supply chain dependencies, which could result in out-of-stock conditions, and its results of operations and relationships with customers could be adversely affected if new or existing suppliers are unable to meet any standards set by the Company, government or industry regulations, or the Company’s customers, if the Company is unable to contract with suppliers at the quantity, quality and price levels needed for its business, if any of the Company’s key suppliers becomes insolvent, ceases or significantly reduces its operations or experiences financial distress, or if any environmental, economic or other outside factors impact its operations. The Company also requires new and existing suppliers to meet its ethical and business partner standards, and if our existing or new suppliers fail to meet such standards or if we are unable to contract with suppliers on favorable terms, our business, results of operations, cash flows and financial condition could be adversely affected. Suppliers may also have to meet governmental and industry standards and any relevant standards required by the Company’s customers, which may require additional investment and time on behalf of suppliers and the Company. In addition, the Company may increase production in-house and reduce its supply and manufacturing arrangements with third parties, which may lead to additional costs connected to such transition and unwinding of certain manufacturing relationships.
13

Table of Contents
The Company experienced significantly elevated demand for disinfecting products and other consumer and professional products during the height of the COVID-19 pandemic, as compared to pre-pandemic levels. This increase caused strain on the Company’s supply chain network and its ability to meet such demand, due to the loss or disruption to the timely availability of adequate supplies of raw materials and finished goods that the Company requires for the manufacture of its products, disruptions and shortages in transportation and logistics operations, and restriction of or disruption in its manufacturing and distribution capacity, among other things. If demand were to increase again in a similar manner, the Company may be unable to fully or substantially meet demand, which could result in, among other things, shortages in the Company's products, unmet consumer demand leading to reduced preference for the Company’s products in the future, customers purchasing products from the Company’s competitors as a result of such shortage of products, strained customer relationships, termination of customer contracts, additional competition and new entrants into the market, and loss of potential sales and revenue, which could adversely affect the Company’s business, financial condition and results of operations.
Cyber-attacks, privacy breaches, data breaches or a failure of key information technology systems could have a material adverse effect on the Company’s business, financial condition, results of operations and reputation.
To conduct its business, the Company relies extensively on information technology systems, many of which are managed, hosted, provided and/or used by third-parties and their vendors. These systems include, but are not limited to, programs and processes relating to communicating within the Company and with customers, consumers, vendors, investors and other parties; ordering and managing materials from suppliers; converting materials to finished products; receiving and processing purchase orders and shipping products to customers; processing transactions; storing, processing and transmitting data, including personal confidential information and payment card industry data; hosting, processing and sharing confidential and proprietary research, business and financial information; and complying with financial reporting, regulatory, legal and tax requirements. Furthermore, the Company sells certain of its natural personal care products, vitamins, minerals, supplements and other products directly to consumers online and through websites, mobile apps and connected devices, and the Company also engages in online activities, including promotions, rebates and customer loyalty and other programs, through which it may receive personal information. Through the use of any of these information technology systems or processes, the Company or its vendors have in the past and could in the future again experience cyber-attacks, privacy breaches, data breaches or other incidents that may result in unauthorized access, disclosure and misuse of consumer, customer, employee, vendor or Company information, especially as the Company shifts to a hybrid working model under which employees will continue accessing its technology infrastructure remotely.
In addition to upgrading the Company’s enterprise resource planning system, it also uses various hardware, software and operating systems that may need to be upgraded or replaced in the near future as such systems cease to be supported by third-party service providers, and may be vulnerable to increased risks, including the risk of security breaches, system failures and disruptions. Any such upgrade could take time, oversight and be costly to the Company. If such systems are not successfully upgraded or replaced in a timely manner, system outages, disruptions or delays, or other issues may arise. If a new system does not function properly, or is not adequately supported by third-party service providers and processes, it could adversely affect the Company’s business and operations, which, in turn, adversely impact the Company’s results of operations and cash flows.
Despite the security measures the Company has in place, the information technology systems, including those of our customers, vendors, suppliers and other third-party service providers with whom we have contracted, have, in the past, and may, in the future, be vulnerable to cyber-threats such as computer viruses or other malicious codes, security breaches, unauthorized access, phishing attacks and other disruptions from employee error, unauthorized uses, system failures, including Internet outages, unintentional or malicious actions of employees or contractors or cyber-attacks by hackers, criminal groups, nation-states and nation-state-sponsored organizations and social-activist organizations. The Company’s information technology systems and its third-party providers’ systems, have been, and will likely continue to be, subject to cyber-threats such as computer viruses or other malicious codes, ransomware, unauthorized access attempts, business email compromise, cyber extortion, denial of service attacks, phishing, social engineering, hacking and other cyberattacks attempting to exploit vulnerabilities. The Company has seen and may continue to see an increase in the number of such attacks as the Company shifts to a hybrid working model under which employees will continue working remotely and accessing its technology infrastructure remotely. In addition, while we have purchased cybersecurity insurance, costs related to a cyberattack may exceed the amount of insurance coverage or be excluded under the terms of our cybersecurity policy. As cyberattacks increase in frequency and magnitude, we may be unable to obtain cybersecurity insurance in amounts and on terms we view as appropriate for our operations.
To date, the Company is not aware that its business or operations have been materially impacted by these attacks. However, the Company’s security efforts and the efforts of its third-party providers may not prevent or timely detect attacks and resulting breaches or breakdowns of the Company’s, or its third-party service providers’, databases or systems. In addition, if the Company or its third-party providers are unable to effectively resolve such breaches or breakdowns on a timely basis, the Company may experience interruptions in its ability to manage or conduct business, as well as reputational harm, governmental fines, penalties, regulatory proceedings, and litigation and remediation expenses. In addition, such incidents could result in
14

Table of Contents
unauthorized disclosure and misuse of material confidential information, including personal information. Cyber threats are becoming more sophisticated, are constantly evolving and are being made by groups and individuals with a wide range of expertise and motives, and this increases the difficulty of detecting and successfully defending against them. We have incurred, and will continue to incur, expenses to comply with privacy and data protection standards and protocols imposed by law, regulation, industry standards and contractual obligations. Increased regulation of data collection, use, and retention practices, including self-regulation and industry standards, changes in existing laws and regulations, including reporting requirements, enactment of new laws and regulations, increased enforcement activity, and changes in interpretation of laws, could increase our cost of compliance and operation, limit our ability to grow our business or otherwise harm our business.
In addition, data breaches or theft of personal information collected by the Company and its third-party service providers as well as Company information and assets have occurred in the past and may occur in the future. The Company is subject to the laws and regulations of various countries where it operates or does business related to solicitation, collection, processing, transferring, storing or use of consumer, customer, vendor or employee information or related data, including the European Union’s General Data Protection Regulation (“GDPR”), which went into effect in May 2018, and the California Consumer Privacy Act of 2018 (“CCPA”), which went into effect in January 2020. These laws and regulations change frequently, and new legislation continues to be introduced and may be interpreted and applied differently from jurisdiction to jurisdiction and may create inconsistent or conflicting requirements. For example, the California Privacy Rights Act (“CPRA”), which was effective on January 1, 2022, modifies the CCPA significantly. Several other states have introduced or passed similar legislation to the CCPA and CPRA, which may impose varying standards and requirements on our data collection, use and processing activities. The changes introduced by data privacy and protection regulations increase the complexity of regulations enacted to protect business and personal data and they subject the Company to additional costs and have required, and may in the future require, costly changes to the Company’s security systems, policies, procedures and practices. These laws and regulations also may result in the Company incurring additional expenses and liabilities in the event of unauthorized access to or disclosure of personal data.
A breach or other breakdown in the Company’s technology, including a cyber-attack, privacy breach, data breach or other incident involving the Company or any of the Company's third-party service providers or vendors, that results in unauthorized disclosure or significant unavailability of business, financial, personal or stakeholder information could adversely affect the Company’s financial condition and results of operations. In addition, if the Company’s service providers, suppliers or customers experience a breach or unauthorized disclosure or system failure, their businesses could be disrupted or otherwise negatively affected, which may result in a disruption in the Company’s supply chain or reduced customer orders or other business operations, which would adversely affect the Company.
These risks also may be present to the extent any of our partners, distributors, joint venture partners or suppliers using separate information systems, not integrated with the information systems of the Company, suffers a cybersecurity incident and could result in increased costs related to our involvement in investigations or notifications conducted by these third parties. These risks may also be present to the extent a business we have acquired that does not use our information systems, experiences a system shutdown, service disruption, or cybersecurity incident. Due to the conflict in Ukraine, there is a possibility that the escalation of tensions could result in cyberattacks that could either directly or indirectly affect our operations.
In addition, we are in the process of a multi-year phased upgrade to our digital and productivity capabilities, including replacing our enterprise resource planning system to enhance operating efficiencies and provide more effective management of our business operations. The upgrade poses several challenges, including training of personnel, migration of data and the potential instability of the new system. If we do not allocate and effectively manage the resources necessary to build and sustain the upgraded technology infrastructure, or if we fail to achieve the expected benefits from this enhancement or it does not operate as designed, our business could be adversely affected.
The Company is subject to risks related to its international operations and international trade.
In fiscal year 2022, 16% of the Company’s net sales were attributable to international markets. The Company faces and will continue to face substantial risks associated with its foreign operations, including, but not limited to:
• changing macroeconomic conditions in our markets, including as a result of inflation, volatile commodity prices and increases in the cost of raw and packaging materials, labor, energy and logistics, which could impact the manufacturing operations of the Company and our third-party partners;
• global or local economic or political instability, geopolitical events, environmental events, civil unrest, work stoppages, labor disputes or widespread health emergencies, such as COVID-19 or other pandemics or epidemics;
• foreign currency fluctuations, including devaluations, currency controls and inflation, which may adversely affect the Company’s ability to do business in certain markets and reduce the U.S. dollar value of revenues, profits or cash flows it generates in non-U.S. markets;
15

Table of Contents
• continued high levels of inflation in Argentina, which have required and may continue to require, the Company to record gains and losses in net earnings to reflect the remeasurement of the Company's non‐U.S. dollar monetary assets and liabilities of Argentina;
• difficulty in obtaining non-local currency (e.g., U.S. dollars) to pay for the raw materials needed to manufacture the Company’s products and contract-manufactured products;
• the imposition of tariffs, trade restrictions, price, profit or other government controls, labor laws, immigration restrictions, travel restrictions, including as a result of COVID-19 or other pandemics or epidemics, import and export laws or other government actions generating a negative impact on the Company’s business, including changes in trade policies that may be implemented and the impact of geopolitical events generally;
• potential disruption from wars and military conflicts, including the conflict in Ukraine, terrorism, kidnapping, and drug‐related or other types of violence;
• employment litigation related to employees, contractors and suppliers, particularly in Argentina;
• potential loss of distribution channels as a result of retailer consolidation;
• increased credit risk of customers, suppliers and distributors, and defaults on obligations of foreign governments;
• potential harm to third parties, the Company’s employees and/or surrounding communities, and related liabilities and damages to the Company’s reputation, from the use, storage and transportation of chlorine in certain international markets where chlorine is used in the production of bleach, whether such actions are undertaken by the Company or by the Company’s business partners;
• lack of well-established or reliable, and impartial legal systems in certain countries where the Company operates, including difficulties in enforcing intellectual property and contractual rights;
• challenges relating to enforcement of or compliance with local laws and regulations and with U.S. laws affecting operations outside of the U.S., including without limitation, the FCPA;
• continuing legal, political and economic uncertainty and disruption from the United Kingdom’s exit from the European Union, including the long-term impact of the bilateral trade and cooperation deal governing the future relationship between the United Kingdom and the European Union; and
• the possibility of nationalization, expropriation of assets or other similar government actions.
All of the foregoing risks could have a significant adverse impact on the Company’s ability to commercialize its products on a competitive basis in international markets and may have a material adverse effect on its business, financial condition and results of operations. The Company’s small sales volume in some countries, relative to some multinational and local competitors, could exacerbate such risks.
For further information regarding Argentina, including its designation as a highly inflationary economy, see “Management’s Discussion and Analysis of Financial Condition and Results of Operations” and the Notes to Consolidated Financial Statements in Exhibit 99.1.
Legal and Regulatory Risks
Government regulations could impose material costs.
Generally, the manufacture, processing, formulation, packaging, labeling, storage, distribution, advertising and sale of the Company’s products and the conduct of its business operations must comply with extensive federal, state and foreign laws and regulations. For example, in the U.S., many of the Company’s products are regulated by the Environmental Protection Agency, the Food and Drug Administration (including applicable current good manufacturing practice regulations) and/or the Consumer Product Safety Commission, and the Company’s product claims and advertising are regulated by the Federal Trade Commission, among other regulatory agencies. Additionally, the Company’s and its suppliers’ manufacturing and distribution operations are also subject to regulation by the Occupational Safety and Health Administration. Most states have agencies that regulate in parallel to these federal agencies. The Company’s international operations are also subject to regulation in each of the foreign jurisdictions in which it manufactures or distributes its products. There is also an increased risk of fraud or corruption in certain foreign jurisdictions and related difficulties in maintaining effective internal controls. Additionally, the Company could be subject to future inquiries or investigations by governmental and other regulatory bodies. Any determination that the Company’s operations or activities are not in compliance with applicable law could expose the Company to future
16

Table of Contents
impairment charges or significant fines, penalties or other sanctions that may result in a reduction in net income or otherwise adversely impact the business and reputation of the Company.
Fluctuations in federal, state, local and foreign taxes or a change to uncertain tax positions, including related interest and penalties, may also impact the Company’s effective tax rate and the Company’s results of operations, and changes in tax laws, including additional guidance issued by the U.S. Treasury Department or the U.S. Internal Revenue Service, could create uncertainty, impact our recorded liability in future periods and have a material impact on the Company’s results of operations.
In particular, because of the Company’s extensive international operations, we could be adversely affected by violations, or allegations of violations, of the FCPA and similar international anti-bribery laws. These anti-bribery laws generally prohibit companies and their intermediaries from making improper payments to government officials or other third parties for the purpose of obtaining or retaining business. We cannot provide assurance that our internal controls policies and procedures that mandate compliance with these laws will protect us from reckless, intentional or unintentional criminal acts committed by our employees, joint-venture partners or agents. Violations of these laws, or allegations of such violations, could disrupt our business and adversely affect our reputation and our business, financial condition and results of operations.
Federal, state and foreign governments may introduce new or expand existing legislation and regulations, or courts or governmental authorities could impose more stringent interpretations of existing legislation and regulations, affecting the Company’s operations, which may require the Company to increase its resources, capabilities and expertise in certain areas. For example, the Company is subject to regulations regarding the transportation, storage or use of certain chemicals to protect the environment, including as a result of evolving climate change standards, and regulations in other areas, such as with respect to “conflict minerals” and subject to increased costs or mandatory funding or financial support for recycling and waste management programs under extended producer responsibility regulation or laws. Such regulations could negatively impact the Company’s ability to obtain raw materials or could increase its acquisition and compliance costs or cause the company to contribute funds to recycling and other waste management infrastructure, thus making our products more costly, less competitive than other competitive products or reduce consumer demand. Furthermore, additional or amended legislation in the areas of ESG disclosure, including the SEC’s proposal on climate change disclosure, healthcare reform, sustainability of packaging, including plastic packaging, executive compensation and corporate governance, could also increase the Company’s costs. The Company is also required to comply with increasingly complex and changing laws and regulations enacted to protect business and personal data in the U.S. and other jurisdictions, including the GDPR, the CCPA and the CPRA, which have and could continue to subject the Company to additional compliance costs.
If the Company is found to be noncompliant with applicable laws and regulations in these or other areas, it could be subject to governmental or regulatory actions, including fines, import detentions, injunctions, product withdrawals or recalls or asset seizures, as well as potential criminal sanctions, any of which could have a material adverse effect on its business. Loss of or failure to obtain necessary permits and registrations, particularly with respect to its charcoal business, could delay or prevent the Company from meeting current product demand, introducing new products, building new facilities or acquiring new businesses and could adversely affect its financial condition and results of operations. In addition, the Company markets and sells products that are subject to regulations relating to dietary supplements. In order to comply with any changes in these laws and regulations, including any changes that result from newly published clinical studies and emerging studies that may assert or prove that ingredients in our products or our products themselves are ineffective or harmful to consumers, the Company may be required to make changes to product formulation, labeling or marketing claims, perform additional testing to substantiate its product claims, make costly changes in its manufacturing processes or supply chain or stop selling certain products until corrective actions have been taken. Any of these developments could increase the Company’s costs significantly, which could have a material adverse effect on the Company’s financial condition and results of operations.
ESG issues, including those related to climate change and sustainability, may have an adverse effect on our business, financial condition and results of operations and damage our reputation.
Companies across all industries are facing increasing scrutiny relating to their ESG policies. Increased focus and activism related to ESG may hinder the Company’s access to capital, as investors may reconsider their capital investment as a result of their assessment of the Company’s ESG practices. In particular, customers, consumers, investors and other stakeholders are increasingly focusing on environmental issues, including climate change, water use, deforestation, plastic waste, and other sustainability concerns. Changing consumer preferences may also result in increased demands regarding plastics and packaging materials, including single-use and non-recyclable plastic packaging, and other components of our products and their environmental impact on sustainability; a growing demand for natural or organic products and ingredients; or increased consumer concerns or perceptions (whether accurate or inaccurate) regarding the effects of ingredients or substances present in certain consumer products. These demands could impact the profitability of some of our products, cause us to incur additional costs, to make changes to our operations, or to make additional commitments, set targets or establish additional goals and take actions to meet them, which could expose us to market, operational and execution costs or risks. In addition, governmental and non-governmental organizations, investors, customers, consumers, our employees and other stakeholders have placed
17

Table of Contents
increasing importance on ESG matters, and depending on their assessment of our ESG practices, certain investors may reconsider their investment in the Company.
Concern over climate change or plastics and packaging materials, in particular, may result in new or increased legal and regulatory requirements to reduce or mitigate impacts to the environment. Increased regulatory requirements, including in relation to various aspects of ESG including SEC’s recent disclosure proposal on climate change, or environmental causes may result in increased compliance or input costs of energy, raw materials or compliance with emissions standards, which may cause disruptions in the manufacture of our products or an increase in operating costs. We may undertake additional costs to control, assess and report on ESG metrics as the nature, scope and complexity of ESG reporting, diligence and disclosure requirements expand. Our ability to achieve any stated goal, target, or objective is subject to numerous factors and conditions, many of which are outside of our control. Any failure to achieve our ESG goals or a perception (whether or not valid) of our failure to act responsibly with respect to the environment or to effectively respond to new, or changes in, legal or regulatory requirements concerning environmental or other ESG matters, or increased operating or manufacturing costs due to increased regulation or environmental causes could adversely affect our business and reputation.
If the Company does not adapt to or comply with new regulations, or fails to meet the ESG goals under its IGNITE Strategy or evolving investor, industry or stakeholder expectations and standards, or if the Company is perceived to have not responded appropriately to the growing concern for ESG issues, customers and consumers may choose to stop purchasing our products or purchase products from another company or a competitor, and the Company’s reputation, business or financial condition may be adversely affected.
Product liability and labeling claims, commercial claims or other legal proceedings could adversely affect the Company’s financial condition and results of operations.
The Company has in the past paid, and may be required in the future to pay, for losses or injuries purportedly caused by its products. Such claims may be based on allegations that, among other things, the Company’s products contain contaminants or provide inadequate instructions or warnings regarding their use, have defective packaging, fail to perform as advertised, or damage property or persons. Product liability, advertising and labeling claims could result in negative publicity that could harm the Company’s reputation, sales and results of operations and the reputation of the Company’s brands. In addition, if any of the Company’s products is found to be defective, the Company may recall such products, which could result in adverse publicity, additional litigation, fines, penalties or other losses. Although the Company maintains product liability insurance coverage, potential product liability claims may be subject to a deductible, exceed the amount of insurance coverage or be excluded under the terms of the policies.
In addition, the Company is, and may in the future become, the subject of, or party to, various pending or threatened legal actions, government investigations and proceedings relating to, among other things, advertising disputes with competitors, consumer class actions, including those related to advertising claims, labor claims, breach of contract claims, antitrust litigation, securities litigation, premises liability claims, data privacy and security disputes, employment litigation related to employees, contractors and suppliers, including class action lawsuits, and litigation in foreign jurisdictions. Such actions, investigations and proceedings may or may not relate to the Company’s responses to, and actions taken in connection with, the COVID-19 pandemic, such as the Company’s partnerships with companies in the industries involving shared-space. The Company has been, and may in the future be, subject to additional claims, proceedings and actions as it expands the products within the dietary supplements category. In general, claims made by or against the Company in litigation, investigations, disputes or other proceedings have been and may in the future be expensive and time-consuming to bring or defend against and could result in settlements, injunctions or damages that could significantly affect its business, financial condition and results of operations and harm its reputation. While it is not possible to predict the final resolution of any current or future litigation, investigations, disputes or proceedings and any reserves taken in connection therewith may not be consistent with their final resolutions, the impact of these matters, including any reserves taken in connection with such matters, on the Company’s business, financial condition and results of operations could be material. See “Management’s Discussion and Analysis of Financial Condition and Results of Operations” and the Notes to Consolidated Financial Statements in Exhibit 99.1 for additional information related to these matters.
Environmental matters create potential liabilities that could adversely affect the Company’s financial condition and results of operations.
The Company must comply with various environmental laws and regulations in the jurisdictions in which it operates, including those relating to air emissions, water discharges, handling and disposal of solid and hazardous wastes, remediation of contamination associated with the use and disposal of hazardous substances and climate change. The Company has incurred, and will continue to incur, significant expenditures and other costs in complying with environmental laws and regulations and in providing physical security for its worldwide operations, and such expenditures reduce the cash flow available to the Company for other purposes.
18

Table of Contents
The Company is currently involved in or has potential liability with respect to the remediation of past contamination in the operation of some of its current and former facilities. In addition, some of its present and former facilities have or had been in operation for many years and, over that time, some of those facilities may have used substances or generated and disposed of wastes that are or may be considered hazardous. It is possible that those sites, as well as disposal sites owned by third parties to whom the Company has sent waste, may be identified and become the subject of remediation. In addition, the Company also handles and/or transports hazardous substances, including but not limited to chlorine, at some of its international production facilities. A release of such chemicals, whether in transit or at the Company’s facilities, due to accident or an intentional act, could result in substantial liability and business disruptions. The Company could also become subject to additional environmental liabilities in the future, whether as a result of new laws and regulations or otherwise, that could result in a material adverse effect on its financial condition and results of operations.
The Company had a recorded liability of $28 million as of both June 30, 2022 and 2021 for its share of aggregate future remediation costs related to certain environmental matters, including response actions at various locations. Two matters, relating to environmental costs associated with one of the Company’s former operations at a site located in Alameda County, California and another relating to operations in Dickinson County, Michigan account for a significant portion of the recorded liability. The Company’s estimated losses related to these matters are sensitive to a variety of uncertain factors, including the ability of third parties to pay their share of the response and remediation obligations, the efficacy of any remediation efforts, changes in any remediation requirements, and the future availability of alternative clean-up technologies, and the Company’s exposure may exceed the amount recorded for these matters. See “Management’s Discussion and Analysis of Financial Condition and Results of Operations” and the Notes to Consolidated Financial Statements in Exhibit 99.1 for additional information related to these liabilities.
Failure to effectively utilize, successfully assert or successfully defend, the Company’s intellectual property rights could impact its competitiveness. If the Company is found to have infringed the intellectual property of rights or cannot obtain necessary intellectual property rights, its competitiveness could be negatively impacted.
The Company relies on intellectual property rights based on trademark, trade secret, patent and copyright laws to protect its brands, products, packaging for its products, inventions and confidential information. There is a risk that the Company will not be able to obtain and perfect its own intellectual property rights or, where appropriate, license intellectual property rights necessary to support new product introductions and product innovations. The Company cannot be certain that these rights, if obtained, will not later be invalidated, circumvented or challenged, and the Company could incur significant costs in connection with legal actions to assert its intellectual property rights or to defend those rights from assertions of invalidity. In addition, even if such rights are obtained in the U.S., the laws of some of the other countries in which the Company’s products are or may be sold may not protect intellectual property rights to the same extent as the laws of the U.S. It is also possible that the Company’s brands may not be available for use in certain countries due to prior third party rights, thereby limiting expansion of the Company’s brands. The Company also licenses certain of its brands to third parties and has increased its focus on licensing its intellectual property in connection with the co-development of products or devices, or promotion and sales relationships with companies in industries operating in public spaces. If other parties infringe the Company’s intellectual property rights, they may dilute or diminish the value of the Company’s brands and products in the marketplace, which could diminish the value that consumers associate with the Company’s brands and harm its net sales. The failure to perfect and protect its intellectual property rights could make the Company less competitive and could have a material adverse effect on its business, financial condition and results of operations.
In addition, if the Company is found to have violated the trademark, trade secret, copyright, patent or other intellectual property rights of others, directly or indirectly, through the use of third-party marks, ideas or technologies, such a finding could result in the need to cease use of such trademark, trade secret, copyrighted work or patented invention in the Company’s business as well as the obligation to pay for past infringement. If holders are willing to permit the Company to continue to use such intellectual property rights, they could require a payment of a substantial amount for continued use of those rights. Either ceasing use or paying such amounts could cause the Company to become less competitive and could have a material adverse effect on the Company’s business, financial condition and results of operations. Even if the Company is not found to infringe a third party’s intellectual property rights, the Company could incur material legal costs and related expenses to defend against such claims of infringement and the Company could incur significant costs associated with suspending its use of the challenged intellectual property rights even if it is ultimately found not to have infringed such rights.
The Company’s business could be negatively impacted as a result of stockholder activism or an unsolicited takeover proposal or a proxy contest.
In recent years, proxy contests and other forms of stockholder activism have been directed against numerous public companies. During fiscal years 2012 and 2011, the Company was the target of an unsolicited takeover proposal from a stockholder activist, which resulted in significant costs to the Company. If such a proposal were to be made again, the Company would likely incur significant costs, which could have an adverse effect on the Company’s financial condition and results of operations.
19

Table of Contents
Stockholder activists may also seek to involve themselves in the governance, strategic direction and operations of the Company through stockholder proposals or otherwise. Such proposals may disrupt the Company’s business and divert the attention of the Company’s management and employees, and any perceived uncertainties as to the Company’s future direction resulting from such a situation could result in the loss of potential business opportunities, the perception that the Company needs a change in the direction of its business, or the perception that the Company is unstable or lacks continuity, which may be exploited by our competitors, cause concern to our current or potential customers, and make it more difficult for the Company to attract and retain qualified personnel and business partners, which could adversely affect the Company’s business. In addition, actions of activist stockholders may cause significant fluctuations in our stock price based on temporary or speculative market perceptions or other factors that do not necessarily reflect the underlying fundamentals and prospects of our business.
Our amended and restated bylaws designate specific courts as the exclusive forum for certain stockholder litigation, which could limit our stockholders’ ability to obtain a judicial forum of their choice for disputes with us.
Our amended and restated bylaws provide that, unless we consent in writing to the selection of an alternative forum, the state courts of Delaware (or if no state court has jurisdiction, the federal district court of the District of Delaware) will, to the fullest extent permitted by law, be the sole and exclusive forum for certain types of actions or proceedings under Delaware statutory or common law. The choice of forum provision in our bylaws does not waive our compliance with our obligations under the federal securities laws and the rules and regulations thereunder. Moreover, the provision does not apply to suits brought to enforce a duty or liability created by the Exchange Act or by the Securities Act.
Our exclusive forum provision may limit the ability of our stockholders to bring a claim in a judicial forum of such stockholders’ choice for disputes with us or our directors, officers or employees, which may discourage such lawsuits, even though an action, if successful, might benefit our stockholders. If a court were to find our exclusive forum provision either to be inapplicable or unenforceable in an action, we may incur additional costs associated with resolving such action in other jurisdictions, all of which may increase our costs of litigation. Any person or entity purchasing or otherwise acquiring any interest in shares of our capital stock will be deemed to have notice of, and consented to, the provisions of our amended and restated bylaws described in the preceding sentences.
Financial and Economic Risks
Profitability and cash flow could suffer if the Company is unable to generate anticipated cost savings, successfully implement its strategies, or efficiently manage supply chain and manufacturing processes.
The Company continues to implement plans to improve its competitive position by setting aggressive annual cost savings targets intended to reduce material costs and manufacturing inefficiencies and realize productivity gains, distribution and logistical efficiencies and overhead reductions. If the Company cannot successfully implement its cost savings plans, the Company may not realize all anticipated benefits, which could adversely affect its long-term strategies. The Company also continues to seek to penetrate new markets and introduce new products and product innovations. These goals and strategies may not be implemented or may fail to achieve the desired results. The Company may also not be able to successfully implement any future price increases, which may negatively affect our profitability and cash flow, and any such price increases may also negatively affect sales volumes. In addition, the Company expects to continue to restructure its operations as necessary to improve operational efficiency, including occasionally opening or closing offices, facilities or plants. Gaining additional efficiencies may become increasingly difficult over time, there may be one-time and other costs and negative impacts on sales growth relating to facility or plant closures or other restructurings and anticipated cost savings and the Company’s strategies may not be implemented or may fail to achieve desired results. If the Company is unable to generate anticipated cost savings, successfully implement its strategies, implement new pricing, efficiently manage its supply chain and manufacturing processes, if we are ineffective or slow in developing and implementing appropriate transformational initiatives, including the recently announced upgrade to our digital and productivity capabilities, or if we are unable to achieve anticipated results and cost savings from the recently announced implementation of the streamlined operating model, the Company’s results of operations could suffer. These plans and strategies could also have a negative impact on the Company’s relationships with employees or customers, which could also adversely affect the Company’s business, financial condition and results of operations.
The estimates and assumptions on which the Company’s financial projections are based may prove to be inaccurate, which may cause its actual results to materially differ from such projections, which may adversely affect the Company’s future profitability, cash flows and stock price.
The Company’s financial projections, including any sales or earnings guidance or outlook it may provide from time to time, are dependent on certain estimates and assumptions related to, among other things, category growth, development and launch of innovative new products, market share projections, product pricing and sale, volume and product mix, foreign exchange rates and volatility, tax rates, commodity prices, distribution, cost savings, accruals for estimated liabilities, including litigation reserves, measurement of benefit obligations for pension and other postretirement benefit plans, and the Company’s ability to
20

Table of Contents
generate sufficient cash flow to reinvest in its existing business, fund internal growth, repurchase its stock, make acquisitions, pay dividends and meet debt obligations. The Company’s financial projections are based on historical experience and on various other estimates and assumptions that the Company believes to be reasonable under the circumstances and at the time they are made, and the Company’s actual results may differ materially from its financial projections, especially in light of the increased difficulty in making such estimates and assumptions as a result of the COVID-19 pandemic and supply chain disruptions. Any material variation between the Company’s financial projections and its actual results may adversely affect the Company’s future profitability, cash flows and stock price.
Increases in the estimated fair value of The Procter & Gamble Co. (“P&G’s”) interest in the Company’s Glad business increase the value of the Company’s obligation to purchase P&G’s interest in the Glad business upon the termination of the venture agreement and may, in the future, adversely affect the Company’s net earnings and cash flow.
In January 2003, the Company entered into a venture agreement with P&G related to the Company’s Glad bags and wraps business. In connection with this agreement, P&G provides research and development support to the Glad business. The agreement with P&G expires in January 2026 unless the parties agree to extend the term. The agreement requires the Company to purchase P&G’s 20% interest at the expiration of its term for cash at fair value as established by predetermined valuation procedures. As of June 30, 2022, 2021 and 2020, the estimated fair value of P&G’s interest was $635 million, $613 million and $610 million, respectively, of which $468 million, $432 million and $400 million, respectively, has been recognized by the Company and is reflected in Other liabilities in the Company’s Consolidated Balance Sheets. The difference between the estimated fair value and the amount recognized, and any future changes in the fair value of P&G’s interest, is charged to Cost of products sold in accordance with the effective interest method over the remaining life of the agreement. The estimated fair value of P&G’s interest, which has increased significantly over the past several years, increased by $155 million from June 30, 2017 to June 30, 2022, primarily as a result of the enactment of H.R.1, also known as the “Tax Cuts and Jobs Act” (the “Tax Act”), and the extension of the venture agreement with, and the related research and development support provided by P&G, and may continue to change up until any such purchase by the Company of P&G’s interest. The key assumptions and estimates used to arrive at the estimated fair value include, but are not limited to, tax rates, the rate at which future cash flows are discounted (discount rate), commodity prices, future volume estimates, net sales and expense growth rates, changes in working capital, capital expenditures, foreign exchange rates, inflation and terminal growth rates. Any changes in such assumptions or estimates could significantly affect such estimated fair value and, accordingly, the value of the Company’s repurchase obligation and may adversely affect the Company’s net earnings up until any such purchase and cash flow at the time of any such purchase. For additional information, see “Management’s Discussion and Analysis of Financial Condition and Results of Operations” and Note 8 of Notes to Consolidated Financial Statements in Exhibit 99.1.
The Company’s indebtedness could have a material adverse effect on its business, financial condition and results of operations and prevent the Company from fulfilling its financial obligations, and the Company may not be able to maintain its current credit ratings, may not continue to pay dividends or repurchase its stock and may not remain in compliance with existing debt covenants.
As of June 30, 2022, the Company had nearly $3 billion of debt. The Company’s indebtedness could have important consequences. For example, it could:
• require the Company to dedicate a substantial portion of its cash flow from operations to payments on its indebtedness, which would reduce the availability of its cash flow to fund working capital requirements, capital expenditures, future acquisitions, dividends, repurchase the Company’s common stock and for other general corporate purposes;
• limit the Company’s flexibility in planning for or reacting to general adverse economic conditions or changes in its business and the industries in which it operates;
• place the Company at a competitive disadvantage compared to its competitors that have less debt; and
• limit, along with the financial and other restrictive covenants in the Company’s debt documents, its ability to borrow additional funds.
The Company may also incur substantial additional indebtedness in the future to fund acquisitions, repurchase stock or fund other activities for general business purposes. In addition, on December 31, 2021, the United Kingdom’s Financial Conduct Authority, the governing body regulating the London Interbank Offered Rate (LIBOR), ceased publishing certain LIBOR reference rates. Borrowings under our revolving credit facility bear interest at a rate derived from the Secured Overnight Financing Rate (“SOFR”), which is a relatively new reference rate and has a very limited history. The future performance of SOFR cannot be predicted based on its limited historical performance. Since the initial publication of SOFR in April 2018, changes in SOFR have, on occasion, been more volatile than changes in other benchmark or market rates, such as United States dollar LIBOR. Additionally, any successor rate to SOFR under our revolving credit facility may not have the same
21

Table of Contents
characteristics as SOFR or LIBOR. As a result, the amount of interest we may pay on our revolving credit facility is difficult to predict.
Further, certain terms of the agreements governing the Company’s over-the-counter derivative instruments contain provisions that require the Company’s credit ratings, assigned by Standard & Poor’s and Moody’s to the Company, to remain at investment-grade or above. As of June 30, 2022, the Company’s Standard & Poor’s and Moody’s ratings were both investment-grade. However, if these credit ratings were to fall below investment-grade, the counterparties to the derivative instruments in net liability positions could request full collateralization, and it may negatively impact the Company’s other financial arrangements, including the supply chain financing arrangement offered by a financial institution to our suppliers, which could, in turn, impact our working capital.
The Company has historically declared and paid quarterly cash dividends on its common stock and has been authorized to repurchase its stock subject to certain limitations under its stock repurchase programs. Any determinations by the board of directors to continue to declare and pay cash dividends on the Company’s common stock or to repurchase the Company’s common stock, however, will be based on a number of factors, including the board of directors’ continuing determination that the repurchase programs and the declaration and payment of dividends are in the best interests of the Company’s stockholders. In the event the Company does not declare and pay a quarterly dividend or discontinues its stock repurchases, the Company’s stock price could be adversely affected.
ITEM 1.B. UNRESOLVED STAFF COMMENTS
None.
ITEM 2. PROPERTIES
The Company owns or leases various manufacturing, distribution, office and research and development facilities, including a leased facility in Pleasanton, CA, which houses the Company’s primary research and development group, as well as other administrative and operational support personnel, and a leased office space in Oakland, CA for its corporate headquarters. Management believes the Company’s facilities are adequate to support the business efficiently.
ITEM 3. LEGAL PROCEEDINGS
The Company is subject to routine litigation incidental to its business in the United States and in international locations, including various lawsuits and claims relating to issues such as contract disputes, product liability, patents and trademarks, advertising, commercial, administrative, employment, antitrust, securities, consumer class actions and other matters. Although the results of claims and litigation cannot be predicted with certainty, based on management’s analysis, it is the opinion of management that the ultimate disposition of these matters, to the extent not previously provided for or disclosed in the Company’s consolidated financial statements in Exhibit 99.1, will not have a material adverse effect, individually or in the aggregate, on the Company’s consolidated financial statements taken as a whole.
ITEM 4. MINE SAFETY DISCLOSURES
Not applicable.
22

Table of Contents
INFORMATION ABOUT OUR EXECUTIVE OFFICERS
The names, ages, year first elected and current titles of each of the executive officers of the Company as of August 10, 2022, are set forth below:

Name | Age | Year First Elected Executive Officer | Title
Linda Rendle | 44 | 2016 | Chief Executive Officer
Stacey Grier | 59 | 2019 | Executive Vice President – Chief Growth and Strategy Officer
Kevin B. Jacobsen | 56 | 2018 | Executive Vice President – Chief Financial Officer
Kirsten Marriner | 49 | 2016 | Executive Vice President – Chief People and Corporate Affairs Officer
Eric Reynolds | 52 | 2015 | Executive Vice President – Chief Operating Officer
Chau Banks | 53 | 2020 | Senior Vice President – Chief Information and Enterprise Analytics Officer
Diego J. Barral | 52 | 2018 | Senior Vice President – General Manager, International Division
Rebecca Dunphey | 44 | 2022 | Senior Vice President – General Manager, Specialty
Matt Gregory | 49 | 2021 | Senior Vice President – Chief Customer Officer
Angela Hilt | 50 | 2020 | Senior Vice President – Chief Legal Officer
Chris Hyder | 47 | 2021 | Senior Vice President – General Manager, Cleaning and Professional Products
Rick McDonald | 62 | 2020 | Senior Vice President – Chief Supply Chain Officer
Michael Ott | 53 | 2022 | Senior Vice President – Chief Research and Development Officer
Eric Schwartz | 50 | 2022 | Senior Vice President – Chief Marketing Officer
Shanique Bonelli-Moore | 42 | 2022 | Vice President - Chief Diversity and Social Impact Officer

There is no family relationship between any of the above-named persons, or between any of such persons and any of the directors of the Company. See Item 10 of Part III of this Report for additional information.
Linda Rendle is the chief executive officer of the Company, a position she has held since September 2020. Prior to this role, she served as the president of the Company from May 2020 to September 2020. She served as executive vice president – cleaning, international, strategy and operations from July 2019 to May 2020. From January 2019 to July 2019, she served as executive vice president – strategy and operations. From June 2018 to January 2019, she served as executive vice president – cleaning and strategy. She served as senior vice president – general manager, cleaning division of the Company, from August 2016 to June 2018, having taken on responsibility for the professional products division in April 2017. She served as vice president – general manager, home care from October 2014 to August 2016. From April 2012 to October 2014, she served as vice president – sales, cleaning division. From August 2011 to April 2012, she served as director of sales planning – litter, food & charcoal. From January 2010 to August 2011, she served as director of sales – supply chain. Ms. Rendle joined the Company in 2003.
Stacey Grier is the executive vice president – chief growth and strategy officer of the Company, a position she has held since March 2022. From January 2019 to March 2022, she served as senior vice president – chief marketing officer, having taken on additional responsibility for enterprise strategy since September 2020. Prior to this role, she served as vice president - brand engagement and enhanced wellness marketing from October 2018 to January 2019. She served as vice president - brand and marketing strategy from October 2016 through October 2018. Prior to joining the Company, she served as chief strategic officer at DDB Worldwide from April 1996 to June 2016. Ms. Grier joined the Company in 2016.
Kevin B. Jacobsen is the executive vice president – chief financial officer of the Company, a position he has held since January 2019. Prior to this role, he served as senior vice president – chief financial officer from April 2018 to January 2019. He served as vice president – financial planning and analysis, from November 2011 through March 2018. Mr. Jacobsen joined the Company in 1995 and has held a number of senior leadership roles in the Company’s finance department over the years, including serving as the finance leader for the specialty division, head of finance for Brazil operations, the product supply organization and various business units.
Kirsten Marriner is the executive vice president – chief people and corporate affairs officer of the Company, a position she has held since December 2020. She was appointed to executive vice president - chief people officer in January 2019. Prior to this role she served as senior vice president – chief people officer from March 2016 to January 2019. Prior to joining the Company, she served as senior vice president and chief human resources officer at Omnicare, from March 2013 to August 2015. She
23

Table of Contents
served in various leadership roles, including as senior vice president, director of talent management and development at Fifth Third Bank, from October 2004 to March 2013. Ms. Marriner joined the Company in 2016.
Eric Reynolds is the executive vice president - chief operating officer of the Company, a position he has held since September 2020. Prior to this role, he served as executive vice president - household and lifestyle of the Company from July 2019 to September 2020. He served as executive vice president – cleaning and Burt’s Bees from January 2019 to July 2019. From January 2015 to January 2019, he served as senior vice president – chief marketing officer. He served as vice president – general manager, Europe, Middle East, Africa and Asia from May 2012 to January 2015. From May 2011 to April 2012, he was director, international business development. From June 2008 to April 2011, he was general manager, Caribbean. Mr. Reynolds joined the Company in 1998.
Chau Banks is the senior vice president – chief information and enterprise analytics officer of the Company, a position she has held since June 2020, having taken on responsibility for enterprise analytics since September 2020. Prior to this role, she served as chief technology and digital officer at Revlon Consumer Products Company from January 2018 to June 2020. From September 2013 to November 2017, she was EVP, CIO and channel integration at New York & Company, Inc. (now RetailWinds Inc.). She has held leadership positions at leading global retailers including COACH, Abercrombie & Fitch and LBrands. She previously served as a management consultant at Capgemini and Ernst & Young. She also previously held positions at Energizer and Kimberly-Clark. Ms. Banks joined the Company in 2020.
Diego J. Barral is the senior vice president – general manager, international of the Company, a position he has held since April 2018. Prior to this role, he served as vice president – general manager, Latin America, from January 2012 to April 2018. Mr. Barral joined the company in 1995 and has served in various finance, procurement, business development and international roles.
Rebecca Dunphey is the senior vice president and general manager – specialty division of the Company, a position she has held since March 2022. Prior to joining Clorox, she was president – personal care for Kimberly-Clark North America from October 2020 to March 2022. Previously, she served as Kimberly-Clark’s president – baby & child care from April 2018 to October 2020 and president – adult and feminine care from September 2016 to March 2018. Ms. Dunphey has extensive general management and brand marketing experience across multiple businesses in the consumer packaged goods industry. Ms. Dunphey joined the Company in 2022.
Matt Gregory is the senior vice president – chief customer officer of the Company, a position he has held since September 2021. Previously, he was vice president – general manager, health & beauty from October 2020 to September 2021, and vice president – general manager, Burt’s Bees from December 2017 to September 2020. From February 2015 through December 2017, he was vice president – general manager, charcoal. Mr. Gregory joined Clorox in 2004 and subsequently held positions of increasing responsibility.
Angela Hilt is the senior vice president – chief legal officer of the Company, a position she has held since December 2020. Prior to this role, she served as vice president – corporate secretary and deputy general counsel from September 2018 to December 2020, and vice president – corporate secretary and associate general counsel from October 2008 to September 2018. She served as senior corporate counsel from December 2005 to October 2008. Ms. Hilt joined the Company in 2005.
Chris Hyder is the senior vice president – cleaning and professional products division of the Company, a position he has held since September 2021. Previously, he was vice president – general manager, cleaning division since July 2019 and vice president – general manager, homecare from September 2018 to July 2019. From January 2016 through September 2018, he was vice president of marketing – cleaning and general manager – laundry. Mr. Hyder joined the Company in 2003 and subsequently held positions of increasing responsibility.
Rick McDonald is the senior vice president – chief supply chain officer of the Company, a position he has held since December 2020. Prior to this role, he served as vice president – global operations from December 2017 to December 2020. He served as vice president – integration, international division from May 2013 to November 2017. Mr. McDonald has held other leadership roles in the Company’s product supply organization, including vice president – global logistics, and vice president – integrator, cleaning division. Mr. McDonald joined the Company in 1992.
Michael Ott is the senior vice president – chief research & development officer and interim sustainability officer of the Company, a position he has held since June 2022. Previously, he served as vice president, research & development – specialty division and interim sustainability officer, a position he held from August 2018 through May 2022, having taken on responsibility for sustainability since November 2021. Previously, he was vice president, research & development – cleaning, international, and professional products divisions, from October 2014 to August 2018. Mr. Ott joined the Company in 1996 as a scientist and has since held positions of increasing responsibility in research & development.
24

Table of Contents
Eric Schwartz is the senior vice president and chief marketing officer of the Company, a position he has held since March 2022. Previously, he was senior vice president and general manager – specialty, from July 2019 to March 2022. Prior to joining Clorox, he was chief marketing officer and general manager at Tyson Foods, poultry segment, from January 2017 to February 2019. Earlier in his career, he held positions of increasing responsibility at Tyson Foods and Henkel. Mr. Schwartz rejoined the Company in 2019 after serving as brand manager at the Company from 2000 to 2004.
Shanique Bonelli-Moore is the vice president and chief diversity and social impact officer of the Company, a position she has held since July 2022. Prior to joining Clorox, she was executive director of inclusion at United Talent Agency from January 2019 to June 2022, and director of corporate communications from April 2018 to December 2018. From November 2016 to April 2018, she was senior director of global internal communications and diversity & inclusion lead at BuzzFeed Entertainment. Earlier in her career, she held positions at leading companies including Anheuser-Busch InBev, NBCUniversal and GE where she focused on corporate communication, diversity, inclusion and belonging.
25

Table of Contents
PART II
ITEM 5. MARKET FOR REGISTRANT’S COMMON EQUITY, RELATED STOCKHOLDER MATTERS AND ISSUER PURCHASES OF EQUITY SECURITIES
Market Information
The Company’s common stock is listed on the New York Stock Exchange. The ticker symbol is CLX.
Holders
The number of record holders of the Company’s common stock as of July 25, 2022, was 9,300 based on information provided by the Company’s transfer agent.
Equity Compensation Plan Information
See Part III, Item 12 hereof, which is incorporated herein by reference.
Issuer Purchases of Equity Securities
In May 2018, the Board of Directors authorized the Company to repurchase up to $2,000 million in shares of common stock on the open market (Open-Market Program), which has no expiration date.
In August 1999, the Board of Directors authorized a stock repurchase program to reduce or eliminate dilution upon the issuance of common stock pursuant to the Company’s stock compensation plans (the Evergreen Program). In November 2005, the Board of Directors authorized the extension of the Evergreen Program to reduce or eliminate dilution in connection with issuances of common stock pursuant to the Company’s 2005 Stock Incentive Plan. The Evergreen Program has no expiration date and has no specified limit as to dollar amount and therefore is not included in column [d] below.
The following table sets forth the purchases of the Company’s securities by the Company and any affiliated purchasers within the meaning of Rule 10b-18(a)(3) (17 CFR 240.10b-18(a)(3)) during the fourth quarter of fiscal year 2022.

| [a] |  | [b] |  | [c] |  | [d]
Period | Total Number of Shares Purchased |  | Average Price Paid per Share (1) |  | Total Number of Shares Purchased as Part of Publicly Announced Plans or Programs |  | Maximum Number (or Approximate Dollar Value) of Shares that May Yet Be Purchased Under the Plans or Programs
April 1 to 30, 2022 | — |  |  | $ | — |  |  | — |  |  | $993 million
May 1 to 31, 2022 | — |  |  | — |  |  | — |  |  | $993 million
June 1 to 30, 2022 | — |  |  | — |  |  | — |  |  | $993 million
| — |  |  | $ | — |  |  | — |  |  |

(1)Average price paid per share in the period includes commission.
ITEM 6. RESERVED
ITEM 7. MANAGEMENT’S DISCUSSION AND ANALYSIS OF FINANCIAL CONDITION AND RESULTS OF OPERATIONS
This information appears under “Management’s Discussion and Analysis of Financial Condition and Results of Operations,” in Exhibit 99.1, which is incorporated herein by reference.
ITEM 7.A. QUANTITATIVE AND QUALITATIVE DISCLOSURES ABOUT MARKET RISK
This information appears under “Quantitative and Qualitative Disclosures about Market Risk” in “Management’s Discussion and Analysis of Financial Condition and Results of Operations,” in Exhibit 99.1, which is incorporated herein by reference.
ITEM 8. FINANCIAL STATEMENTS AND SUPPLEMENTARY DATA
These statements and data appear in Exhibit 99.1, which is incorporated herein by reference.
26

Table of Contents
ITEM 9. CHANGES IN AND DISAGREEMENTS WITH ACCOUNTANTS ON ACCOUNTING AND FINANCIAL DISCLOSURE
None.
ITEM 9.A. CONTROLS AND PROCEDURES
Disclosure Controls and Procedures
The Company’s management, with the participation of the Company’s chief executive officer and chief financial officer, evaluated the effectiveness of the Company’s disclosure controls and procedures as of the end of the period covered by this Report. Based on that evaluation, the chief executive officer and chief financial officer concluded that the Company’s disclosure controls and procedures, as of the end of the period covered by this Report, were effective such that the information required to be disclosed by the Company in reports filed under the Exchange Act is (i) recorded, processed, summarized and reported within the time periods specified in the SEC’s rules and forms and (ii) accumulated and communicated to management, including the chief executive officer and chief financial officer, as appropriate to allow timely decisions regarding disclosure.
Management’s Report on Internal Control Over Financial Reporting
Management’s report on internal control over financial reporting is set forth in Exhibit 99.1, and is incorporated herein by reference. The Company’s independent registered public accounting firm, Ernst & Young, LLP, has audited the effectiveness of the Company’s internal control over financial reporting as of June 30, 2022. See “Report of Independent Registered Public Accounting Firm,” which appears in Exhibit 99.1.
Change in Internal Control Over Financial Reporting
No change in the Company’s internal control over financial reporting occurred during the fourth fiscal quarter of the fiscal year ended June 30, 2022, that has materially affected, or is reasonably likely to materially affect, the Company’s internal control over financial reporting.
ITEM 9.B. OTHER INFORMATION
Not applicable.
ITEM 9.C. DISCLOSURE REGARDING FOREIGN JURISDICTIONS THAT PREVENT INSPECTIONS
Not applicable.
27

Table of Contents
PART III
ITEM 10. DIRECTORS, EXECUTIVE OFFICERS AND CORPORATE GOVERNANCE
See “Information about our Executive Officers” in Part I of this Report.
The Company has adopted a Code of Conduct that applies to its principal executive officer, principal financial officer and principal accounting officer, among others. The Code of Conduct is located on the Company’s website at TheCloroxCompany.com under Who We Are/Corporate Governance/Code of Conduct or https://www.thecloroxcompany.com/who-we-are/corporate-governance/codes-of-conduct/. The Company intends to satisfy the requirement under Item 5.05 of Form 8-K regarding disclosure of amendments to, or waivers from, provisions of its Code of Conduct by posting such information on the Company’s website. The Company’s website also contains its corporate governance guidelines and the charters of its principal board committees.
Information regarding the Company’s directors and corporate governance set forth in the Proxy Statement is incorporated herein by reference.
ITEM 11. EXECUTIVE COMPENSATION
Information regarding executive and director compensation, Management Development and Compensation Committee interlocks and insider participation and the report of the Management Development and Compensation Committee of the Company’s board of directors set forth in the Proxy Statement is incorporated herein by reference.
ITEM 12. SECURITY OWNERSHIP OF CERTAIN BENEFICIAL OWNERS AND MANAGEMENT AND RELATED STOCKHOLDER MATTERS
Information regarding security ownership of certain beneficial owners, management and directors and securities authorized for issuance under equity compensation plans set forth in the Proxy Statement is incorporated herein by reference.
ITEM 13. CERTAIN RELATIONSHIPS AND RELATED TRANSACTIONS, AND DIRECTOR INDEPENDENCE
Information regarding certain relationships and related transactions and director independence set forth in the Proxy Statement is incorporated herein by reference.
ITEM 14. PRINCIPAL ACCOUNTANT FEES AND SERVICES
Information regarding principal accountant fees and services set forth in the Proxy Statement is incorporated herein by reference.
28

Table of Contents
PART IV
ITEM 15. EXHIBITS AND FINANCIAL STATEMENT SCHEDULES
(a)Financial Statements and Schedules:
Consolidated Financial Statements and Reports of Independent Registered Public Accounting Firm included in Exhibit 99.1, incorporated herein by reference.
Reports of Ernst & Young, LLP, Independent Registered Public Accounting Firm (PCAOB ID: 42).
Consolidated Statements of Earnings for the fiscal years ended June 30, 2022, 2021 and 2020.
Consolidated Statements of Comprehensive Income for the fiscal years ended June 30, 2022, 2021 and 2020.
Consolidated Balance Sheets as of June 30, 2022 and 2021.
Consolidated Statements of Stockholders’ Equity for the fiscal years ended June 30, 2022, 2021 and 2020.
Consolidated Statements of Cash Flows for the fiscal years ended June 30, 2022, 2021 and 2020.
Notes to Consolidated Financial Statements.
(b)Exhibits:
INDEX TO EXHIBITS

|  |  |  | Incorporated by Reference
Exhibit Number |  | Exhibit Description |  | Form |  | File No. |  | Exhibit |  | Filing Date
3.1 |  | Restated Certificate of Incorporation. |  | 10-K |  | 001-07151 |  | 3.1 |  | August 14, 2018
3.2 |  | Bylaws (amended and restated). |  | 8-K |  | 001-07151 |  | 3.2 |  | September 15, 2016
3.3 |  | Certificate of Designations for The Clorox Company Series A Junior Participating Preferred Stock. |  | 8-K |  | 001-07151 |  | 3.1 |  | July 19, 2011
4.1 |  | Indenture, dated as of October 9, 2007, between the Company and The Bank of New York Trust Company N.A., as trustee. |  | S-3ASR |  | 333-200722 |  | 4.1 |  | December 4, 2014
4.2 |  | Fourth Supplemental Indenture, dated as of September 13, 2012, between the Company and Wells Fargo Bank, National Association, as trustee. |  | S-3ASR |  | 333-200722 |  | 4.5 |  | December 4, 2014
4.3 |  | Fifth Supplemental Indenture, dated as of December 9, 2014, between the Company and Wells Fargo Bank, National Association, as trustee. |  | 8-K |  | 001-07151 |  | 4.1 |  | December 9, 2014
4.4 |  | Sixth Supplemental Indenture, dated as of September 28, 2017, between the Company and Wells Fargo Bank, National Association, as trustee. |  | 8-K |  | 001-07151 |  | 4.1 |  | September 28, 2017
4.5 |  | Seventh Supplemental Indenture, dated as of May 9, 2018, between the Company and Wells Fargo Bank, National Association, as trustee. |  | 8-K |  | 001-07151 |  | 4.1 |  | May 9, 2018
4.6 |  | Eighth Supplemental Indenture, dated as of May 8, 2020, between the Company and Wells Fargo Bank, National Association, as trustee. |  | 8-K |  | 001-07151 |  | 4.1 |  | May 8, 2020
4.7 |  | Indenture dated as of May 11, 2022, between the Company and U.S. Bank Trust Company, National Association, as trustee |  | 8-K |  | 001-07151 |  | 4.1 |  | May 11, 2022
4.8 |  | Description of Capital Stock of The Clorox Company |  | 10-K |  | 001-07151 |  | 4.10 |  | August 14, 2019
10.1* |  | The Clorox Company Amended and Restated Independent Directors’ Deferred Compensation Plan, effective as of November 16, 2005, and amended and restated as of February 7, 2008. |  | 10-Q |  | 001-07151 |  | 10.55 |  | May 2, 2008

29

Table of Contents

|  |  |  | Incorporated by Reference
Exhibit Number |  | Exhibit Description |  | Form |  | File No. |  | Exhibit |  | Filing Date
10.2* |  | The Clorox Company Non-Qualified Deferred Compensation Plan, adopted as of January 1, 1996, and amended and restated as of July 20, 2004. |  | 10-K |  | 001-07151 |  | 10(x) |  | August 27, 2004
10.3* |  | Amendment No.1 to The Clorox Company Non-Qualified Deferred Compensation Plan. |  | 10-K |  | 001-07151 |  | 10.3 |  | August 16, 2016
10.4* |  | The Clorox Company Annual Incentive Plan, amended and restated as of September 21, 2021. |  | 10-Q |  | 001-07151 |  | 10.1 |  | November 1, 2021
10.5* |  | The Clorox Company 2005 Stock Incentive Plan, amended and restated as of November 17, 2021. |  | DEF 14A |  | 001-07151 |  | App. A |  | October 6, 2021
10.6* |  | Form of Performance Share Award Agreement under the Company's 2005 Stock Incentive Plan for awards made in 2019. |  | 10-Q |  | 001-07151 |  | 10.1 |  | October 31, 2019
10.7* |  | Form of Performance Share Award Agreement under the Company’s 2005 Stock Incentive Plan for awards made in 2020. |  | 10-Q |  | 001-07151 |  | 10.4 |  | November 2, 2020
10.8* |  | Form of Performance Share Award Agreement under the Company’s 2005 Stock Incentive Plan for awards made in 2021. |  | 10-Q |  | 001-07151 |  | 10.4 |  | November 1, 2021
10.9* |  | Form of Nonqualified Stock Option Award Agreement under the Company’s 2005 Stock Incentive Plan. |  | 10-Q |  | 001-07151 |  | 10.3 |  | November 1, 2021
10.10* |  | Form of Restricted Stock Unit Award Agreement under the Company's 2005 Stock Incentive Plan (Annual Grant). |  | 10-Q |  | 001-07151 |  | 10.5 |  | November 1, 2021
10.11* |  | Form of Restricted Stock Unit Award Agreement under the Company's 2005 Stock Incentive Plan (Off-Cycle Grant). |  | 10-Q |  | 001-07151 |  | 10.6 |  | November 1, 2021
10.12* |  | The Clorox Company Amended and Restated 2005 Nonqualified Deferred Compensation Plan, effective January 1, 2008. |  | 10-K |  | 001-07151 |  | 10.18 |  | August 19, 2008
10.13* |  | Amendment No. 1 to The Clorox Company Amended and Restated 2005 Nonqualified Deferred Compensation Plan. |  | 10-K |  | 001-07151 |  | 10.18 |  | August 26, 2011
10.14* |  | Amendment No. 2 to The Clorox Company Amended and Restated 2005 Nonqualified Deferred Compensation Plan. |  | 10-K |  | 001-07151 |  | 10.13 |  | August 16, 2016
10.15* |  | The Clorox Company Supplemental Executive Retirement Plan, as restated effective January 5, 2005, as revised August 13, 2009. |  | 10-Q |  | 001-07151 |  | 10.17 |  | November 3, 2009
10.16* |  | Amendment No. 1 to The Clorox Company Supplemental Executive Retirement Plan, effective as of July 29, 2011. |  | 10-Q |  | 001-07151 |  | 10.21 |  | November 3, 2011
10.17* |  | Amendment No. 2 to The Clorox Company Supplemental Executive Retirement Plan, effective as of September 11, 2012. |  | 10-Q |  | 001-07151 |  | 10.2 |  | November 2, 2012
10.18* |  | Amendment No. 3 to The Clorox Company Supplemental Executive Retirement Plan, effective as of March 28, 2018. |  | 10-Q |  | 001-07151 |  | 10.1 |  | May 2, 2018
10.19* |  | Form of Indemnification Agreement. |  | 10-Q |  | 001-07151 |  | 10.27 |  | May 4, 2010
10.20* |  | Third Amended and Restated Executive Change in Control Severance Plan, effective November 17, 2021. |  | 8-K |  | 001-07151 |  | 10.2 |  | November 17, 2021
10.21* |  | Severance Plan for Clorox Executive Committee Members, fourth amended and restated effective November 17, 2021. |  | 8-K |  | 001-07151 |  | 10.3 |  | November 17, 2021
10.22* |  | The Clorox Company Executive Retirement Plan, effective as of July 1, 2011. |  | 10-Q |  | 001-07151 |  | 10.27 |  | May 4, 2011
10.23* |  | Amendment No. 1 to The Clorox Company Executive Retirement Plan. |  | 10-K |  | 001-07151 |  | 10.22 |  | August 16, 2016
10.24* |  | The Clorox Company 2011 Nonqualified Deferred Compensation Plan, effective as of July 1, 2011. |  | 10-K |  | 001-07151 |  | 10.29 |  | August 26, 2011
10.25* |  | Amendment No. 1 to The Clorox Company 2011 Nonqualified Deferred Compensation Plan. |  | 10-K |  | 001-07151 |  | 10.24 |  | August 16, 2016

30

Table of Contents

|  |  |  | Incorporated by Reference
Exhibit Number |  | Exhibit Description |  | Form |  | File No. |  | Exhibit |  | Filing Date
10.26* |  | The Clorox Company Director Equity Award Policy, effective as of November 15, 2017. |  | 10-K |  | 001-07151 |  | 10.26 |  | August 14, 2018
10.27 |  | Credit Agreement dated as of March 25, 2022, among The Clorox Company, the lenders listed therein, JPMorgan Chase Bank, N.A., Citibank, N.A., and Wells Fargo Bank, National Association, as Administrative Agents, and JPMorgan Chase Bank, N.A., as Servicing Agent. |  | 8-K |  | 001-07151 |  | 10.1 |  | March 28, 2022
10.28 |  | Amended and Restated Joint Venture Agreement dated as of January 31, 2003, between The Glad Products Company and certain affiliates and The Procter and Gamble Company and certain affiliates. |  | 10-K/A |  | 001-07151 |  | 10.26 |  | September 30, 2016
10.29 |  | Amendment No. 1 to the Amended and Restated Joint Venture Agreement, dated as of October 15, 2010, between The Glad Products Company and certain affiliates and The Procter & Gamble Company and certain affiliates. |  | 10-Q |  | 001-07151 |  | 10.2 |  | February 2, 2018
10.30 |  | First Extension and Amendment of the Amended and Restated Joint Venture Agreement, dated as of December 20, 2017, between The Glad Products Company and certain affiliates and The Procter & Gamble Company and certain affiliates. |  | 10-Q |  | 001-07151 |  | 10.1 |  | February 2, 2018
10.31 |  | Acknowledgement Letter to the Amended and Restated Joint Venture Agreement, dated as of October 7, 2020, between The Glad Products Company and certain affiliates and The Procter & Gamble Company and certain affiliates. |  | 10-Q |  | 001-07151 |  | 10.2 |  | February 4, 2021
21 |  | Subsidiaries. |  |  |  |  |  |  |  |
23 |  | Consent of Independent Registered Public Accounting Firm. |  |  |  |  |  |  |  |
31.1 |  | Certification of the Chief Executive Officer of The Clorox Company pursuant to Section 302 of the Sarbanes-Oxley Act of 2002. |  |  |  |  |  |  |  |
31.2 |  | Certification of the Chief Financial Officer of The Clorox Company pursuant to Section 302 of the Sarbanes-Oxley Act of 2002. |  |  |  |  |  |  |  |
32 |  | Certification of the Chief Executive Officer and Chief Financial Officer of The Clorox Company pursuant to Section 906 of the Sarbanes-Oxley Act of 2002. |  |  |  |  |  |  |  |
99.1 |  | Management’s Discussion and Analysis of Financial Condition and Results of Operations, Consolidated Financial Statements, Management’s Report on Internal Control over Financial Reporting and Reports of Independent Registered Public Accounting Firm. |  |  |  |  |  |  |  |
99.2 |  | Reconciliation of Economic Profit (Unaudited). |  |  |  |  |  |  |  |
101.INS |  | XBRL Instance Document - the instance document does not appear in the Interactive Data File because its XBRL tags are embedded within the Inline XBRL document. |  |  |  |  |  |  |  |
101.SCH |  | XBRL Taxonomy Extension Schema Document. |  |  |  |  |  |  |  |
101.CAL |  | XBRL Taxonomy Extension Calculation Linkbase Document. |  |  |  |  |  |  |  |
101.DEF |  | XBRL Taxonomy Extension Definition Linkbase Document. |  |  |  |  |  |  |  |
101.LAB |  | XBRL Taxonomy Extension Label Linkbase Document. |  |  |  |  |  |  |  |
101.PRE |  | XBRL Taxonomy Extension Presentation Linkbase Document. |  |  |  |  |  |  |  |
104 |  | Cover Page Interactive Data File (embedded within the Inline XBRL document and included in Exhibit 101). |  |  |  |  |  |  |  |

____________________
(*) Indicates a management or director contract or compensatory plan or arrangement required to be filed as an exhibit to this report.
31

Table of Contents
ITEM 16. FORM 10-K SUMMARY
None.
32

SIGNATURES
Pursuant to the requirements of Section 13 or 15(d) of the Securities Exchange Act of 1934, the registrant has duly caused this report to be signed on its behalf by the undersigned, thereunto duly authorized.

| THE CLOROX COMPANY
Date: August 10, 2022 | By: | /s/ Linda Rendle
|  | Linda Rendle
|  | Chief Executive Officer

Pursuant to the requirements of the Securities Exchange Act of 1934, this report has been signed below by the following persons on behalf of the registrant and in the capacities and on the dates indicated.

Signature |  | Title |  | Date
/s/ A. Banse |  | Director |  | August 10, 2022
A. Banse |  |  |  |
/s/ R. H. Carmona |  | Director |  | August 10, 2022
R. H. Carmona |  |  |  |
/s/ J. Denman |  | Director |  | August 10, 2022
J. Denman |  |  |  |
/s/ S. C. Fleischer |  | Director |  | August 10, 2022
S. C. Fleischer |  |  |  |
/s/ E. Lee |  | Director |  | August 10, 2022
E. Lee |  |  |  |
/s/ A. D. D. Mackay |  | Director |  | August 10, 2022
A. D. D. Mackay |  |  |  |
/s/ P. Parker |  | Director |  | August 10, 2022
P. Parker |  |  |  |
/s/ S. Plaines |  | Director |  | August 10, 2022
S. Plaines |  |  |  |
/s/ M. J. Shattock |  | Independent Chair |  | August 10, 2022
M. J. Shattock |  |  |  |
/s/ K. Tesija |  | Director |  | August 10, 2022
K. Tesija |  |  |  |
/s/ R. J. Weiner |  | Director |  | August 10, 2022
R. J. Weiner |  |  |  |
/s/ C. J. Williams |  | Director |  | August 10, 2022
C. J. Williams |  |  |  |
/s/ L. Rendle |  | Chief Executive Officer (Principal Executive Officer) |  | August 10, 2022
L. Rendle |  |  |
/s/ K. B. Jacobsen |  | Executive Vice President – Chief Financial Officer (Principal Financial Officer) |  | August 10, 2022
K. B. Jacobsen |  |  |
/s/ L. Peck |  | Vice President – Chief Accounting Officer and Corporate Controller (Principal Accounting Officer) |  | August 10, 2022
L. Peck |  |  |

33